@@ -11,7 +11,7 @@
     copyright: (C) 2002 by Dario Abatianni
     email:     eisfuchs@tigress.com
 
-    $Id: channel.cpp,v 1.62 2003/03/19 16:14:44 eisfuchs Exp $
+    $Id: channel.cpp,v 1.79 2003/05/13 13:32:51 eisfuchs Exp $
 */
 
 #include <qvbox.h>
@@ -21,7 +21,6 @@
 #include <qheader.h>
 #include <qregexp.h>
 #include <qtooltip.h>
-#include <qtextcodec.h>
 #include <qsplitter.h>
 
 #include <klocale.h>
@@ -49,6 +48,9 @@ Channel::Channel(QWidget* parent) : ChatWindow(parent)
   splitterChanged=true;
   modeButtonsChanged=false;
   modeButtonsState=false;
+  
+  // flag for first seen topic
+  topicAuthorUnknown=true;
 
   setType(ChatWindow::Channel);
 
@@ -63,9 +65,8 @@ Channel::Channel(QWidget* parent) : ChatWindow(parent)
   splitter=new QSplitter(this);
   setStretchFactor(splitter,10);
   splitter->setOpaqueResize(true);
-  
+
   // The grid for the topic line, Nicks/Ops label, Channel View and Nick list
-//  QGrid* topicViewNicksGrid=new QGrid(2,this);
   QVBox* topicViewNicksGrid=new QVBox(splitter);
   topicViewNicksGrid->setSpacing(spacing());
 
@@ -126,11 +127,13 @@ Channel::Channel(QWidget* parent) : ChatWindow(parent)
   nicknameListView->setSelectionModeExt(KListView::Extended);
   nicknameListView->setAllColumnsShowFocus(true);
   nicknameListView->setSorting(1,true);
-  nicknameListView->addColumn(QString::null,2);
+  nicknameListView->addColumn(QString::null);
   nicknameListView->addColumn(QString::null);
   nicknameListView->addColumn(QString::null);
   nicknameListView->header()->hide();
-  nicknameListView->setFont(KonversationApplication::preferences.getListFont());
+//  nicknameListView->setResizeMode(KListView::LastColumn);
+  nicknameListView->setColumnWidthMode(1,KListView::Maximum);
+  nicknameListView->setColumnWidthMode(2,KListView::Maximum);
 
   // the grid that holds the quick action buttons
   buttonsGrid=new QGrid(2,nickListButtons);
@@ -191,8 +194,11 @@ Channel::Channel(QWidget* parent) : ChatWindow(parent)
   connect(channelInput,SIGNAL (nickCompletion()),this,SLOT (completeNick()) );
   connect(channelInput,SIGNAL (textPasted(QString)),this,SLOT (textPasted(QString)) );
   
-  connect(textView,SIGNAL (newText()),this,SLOT (newTextInView()) );
-  connect(textView,SIGNAL (newURL(const QString &)),this, SLOT (urlCatcher(const QString &)) );
+  connect(channelInput,SIGNAL (pageUp()),getTextView(),SLOT (pageUp()) );
+  connect(channelInput,SIGNAL (pageDown()),getTextView(),SLOT (pageDown()) );
+  
+  connect(textView,SIGNAL (newText(const QString&)),this,SLOT (newTextInView(const QString&)) );
+  connect(textView,SIGNAL (newURL(const QString&)),this, SLOT (urlCatcher(const QString&)) );
   connect(textView,SIGNAL (gotFocus()),this,SLOT (adjustFocus()) );
   connect(textView,SIGNAL (sendFile()),this,SLOT (sendFileMenu()) );
 
@@ -204,7 +210,12 @@ Channel::Channel(QWidget* parent) : ChatWindow(parent)
 
   nicknameList.setAutoDelete(true);     // delete items when they are removed
 
+  updateFonts();
   setLog(KonversationApplication::preferences.getLog());
+
+  connect(&userhostTimer,SIGNAL (timeout()),this,SLOT (autoUserhost()));
+  // every few seconds try to get more userhosts
+  userhostTimer.start(10000);
 }
 
 Channel::~Channel()
@@ -212,7 +223,7 @@ Channel::~Channel()
   kdDebug() << "Channel::~Channel()" << endl;
 
   KonversationApplication::preferences.setChannelSplitter(splitter->sizes());
-  
+
   // Purge nickname list
   Nick* nick=nicknameList.first();
   while(nick)
@@ -228,10 +239,7 @@ Channel::~Channel()
 
 void Channel::requestNewTopic(const QString& newTopic)
 {
-  kdDebug() << "requestNewTopic(" << newTopic << ")" << endl;
-
-  QTextCodec* codec=QTextCodec::codecForName(KonversationApplication::preferences.getCodec());
-  topicLine->setCurrentText(codec->toUnicode(topic));
+  topicLine->setCurrentText(topic);
 
   if(newTopic!=topic) sendChannelText(KonversationApplication::preferences.getCommandChar()+"TOPIC "+newTopic);
 
@@ -242,9 +250,15 @@ void Channel::textPasted(QString text)
 {
   if(server)
   {
-    // TODO: make sure that lines starting with / get extended to //
     QStringList multiline=QStringList::split('\n',text);
-    for(unsigned int index=0;index<multiline.count();index++) sendChannelText(multiline[index]);
+    for(unsigned int index=0;index<multiline.count();index++)
+    {
+      QString line=multiline[index];
+      QString cChar(KonversationApplication::preferences.getCommandChar());
+      // make sure that lines starting with command char get escaped
+      if(line.startsWith(cChar)) line=cChar+line;
+      sendChannelText(line);
+    }
   }
 }
 
@@ -252,6 +266,8 @@ void Channel::textPasted(QString text)
 void Channel::popupCommand(int id)
 {
   QString pattern;
+  QString cc=KonversationApplication::preferences.getCommandChar();
+
   bool raw=false;
 
   switch(id)
@@ -291,33 +307,72 @@ void Channel::popupCommand(int id)
       }
       break;
     case NickListView::Kick:
-      pattern="KICK %c %u";
-      raw=true;
+      pattern=cc+"KICK %u";
+      break;
+    case NickListView::KickBan:
+      pattern=cc+"BAN %u\n"+
+              cc+"KICK %u";
+      break;
+    case NickListView::BanNick:
+      pattern=cc+"BAN %u";
+      break;
+    case NickListView::BanHost:
+      pattern=cc+"BAN -HOST %u";
+      break;
+    case NickListView::BanDomain:
+      pattern=cc+"BAN -DOMAIN %u";
+      break;
+    case NickListView::BanUserHost:
+      pattern=cc+"BAN -USERHOST %u";
+      break;
+    case NickListView::BanUserDomain:
+      pattern=cc+"BAN -USERDOMAIN %u";
+      break;
+    case NickListView::KickBanHost:
+      pattern=cc+"BAN -HOST %u\n"+
+              cc+"KICK %u";
+      break;
+    case NickListView::KickBanDomain:
+      pattern=cc+"BAN -DOMAIN %u\n"+
+              cc+"KICK %u";
+      break;
+    case NickListView::KickBanUserHost:
+      pattern=cc+"BAN -USERHOST %u\n"+
+              cc+"KICK %u";
+      break;
+    case NickListView::KickBanUserDomain:
+      pattern=cc+"BAN -USERDOMAIN %u\n"+
+              cc+"KICK %u";
       break;
     case NickListView::Query:
-      pattern=KonversationApplication::preferences.getCommandChar()+"QUERY %u";
+      pattern=cc+"QUERY %u";
       break;
     case NickListView::DccSend:
-      pattern=KonversationApplication::preferences.getCommandChar()+"DCC SEND %u";
+      pattern=cc+"DCC SEND %u";
       break;
   } // switch
 
-  if(pattern.length())
+  if(!pattern.isEmpty())
   {
     pattern.replace(QRegExp("%c"),getName());
 
     QStringList nickList=getSelectedNicksList();
 
     QString command;
-    for(QStringList::Iterator index=nickList.begin();index!=nickList.end();++index)
+    for(QStringList::Iterator nickIterator=nickList.begin();nickIterator!=nickList.end();++nickIterator)
     {
-      command=pattern;
-      command.replace(QRegExp("%u"),*index);
+      QStringList patternList=QStringList::split('\n',pattern);
 
-      if(raw)
-        server->queue(command);
-      else
-        sendChannelText(command);
+      for(unsigned int index=0;index<patternList.count();index++)
+      {
+        command=patternList[index];
+        command.replace(QRegExp("%u"),*nickIterator);
+
+        if(raw)
+          server->queue(command);
+        else
+          sendChannelText(command);
+      }
     }
   }
 }
@@ -339,101 +394,101 @@ void Channel::completeNick()
 
   QString line=channelInput->text();
   QString newLine;
-  /* Check if completion position is out of range */
+  // Check if completion position is out of range
   if(completionPosition>=nicknameList.count()) completionPosition=0;
-  /* Check, which completion mode is active */
+  // Check, which completion mode is active
   char mode=channelInput->getCompletionMode();
-  /* Are we in query mode? */
+  // Are we in query mode?
   if(mode=='q')
   {
-    /* Remove /msg <nick> part from string */
+    // Remove /msg <nick> part from string
     line=line.mid(pos);
-    /* Set cursor to beginning to restart query completion */
+    // Set cursor to beginning to restart query completion
     pos=0;
   }
-  /* Or maybe in channel mode? */
+  // Or maybe in channel mode?
   else if(mode=='c')
   {
     line.remove(oldPos,pos-oldPos);
     pos=oldPos;
   }
-  /* If the cursor is at beginning of line, insert /msq <query> */
+  // If the cursor is at beginning of line, insert /msq <query>
   if(pos==0)
   {
-    /* Find next query in list */
+    // Find next query in list
     QString queryName=server->getNextQueryName();
-    /* Sis we find any queries? */
-    if(queryName)
+    // Did we find any queries?
+    if(!queryName.isEmpty())
     {
-      /* Prepend /msg name */
+      // Prepend /msg name
       newLine="/msg "+queryName+" ";
-      /* New cursor position is behind nickname */
+      // New cursor position is behind nickname
       pos=newLine.length();
-      /* Add rest of the line */
+      // Add rest of the line
       newLine+=line;
-      /* Set query completion mode */
+      // Set query completion mode
       channelInput->setCompletionMode('q');
     }
-    /* No queries at all, so ignore this TAB */
+    // No queries at all, so ignore this TAB
     else newLine=line;
   }
   else
   {
-    /* Set channel nicks completion mode */
+    // set channel nicks completion mode
     channelInput->setCompletionMode('c');
-    /* Remember old cursor position in input field */
+    // remember old cursor position in input field
     channelInput->setOldCursorPosition(pos);
-    /* remember old cursor position locally */
+    // remember old cursor position locally
     oldPos=pos;
-    /* remember old nick completion position */
+    // remember old nick completion position
     unsigned int oldCompletionPosition=completionPosition;
-    /* step back to last space or start of line */
+    // step back to last space or start of line
     while(pos && line[pos-1]!=' ') pos--;
-    /* copy search pattern (lowercase) */
+    // copy search pattern (lowercase)
     QString pattern=line.mid(pos,oldPos-pos).lower();
-    /* copy line to newLine-buffer */
+    // copy line to newLine-buffer
     newLine=line;
-    /* did we find any pattern? */
-    if(pattern && pattern.length())
+    // did we find any pattern?
+    if(!pattern.isEmpty())
     {
       QString foundNick(QString::null);
-      /* Try to find matching nickname in list of names */
+      // try to find matching nickname in list of names
       do
       {
         QString lookNick=nicknameList.at(completionPosition)->getNickname();
         if(lookNick.lower().startsWith(pattern)) foundNick=lookNick;
-        /* increment search position */
+        // increment search position
         completionPosition++;
-        /* wrap around */
+        // wrap around
         if(completionPosition==nicknameList.count()) completionPosition=0;
-        /* the search ends when we either find a suitable nick or we end up at the
-           first search position */
-      } while(completionPosition!=oldCompletionPosition && foundNick.length()==0);
-      /* Did we find a suitable nick? */
-      if(foundNick.length())
+        // the search ends when we either find a suitable nick or we end up at the
+        // first search position
+      } while(completionPosition!=oldCompletionPosition && foundNick.isEmpty());
+      // did we find a suitable nick?
+      if(!foundNick.isEmpty())
       {
         QString addStart(KonversationApplication::preferences.getNickCompleteSuffixStart());
         QString addMiddle(KonversationApplication::preferences.getNickCompleteSuffixMiddle());
-        /* remove pattern from line */
+        // remove pattern from line
         newLine.remove(pos,pattern.length());
-        /* did we find the nick in the middle of the line? */
+        // did we find the nick in the middle of the line?
         if(pos)
         {
           newLine.insert(pos,foundNick+addMiddle);
           pos=pos+foundNick.length()+addMiddle.length();
         }
-        /* No, it was at the beginning, so insert "Nick: " */
+        // no, it was at the beginning
         else
         {
           newLine.insert(pos,foundNick+addStart);
           pos=pos+foundNick.length()+addStart.length();
         }
       }
-      /* No pattern found, so restore old cursor position */
+      // no pattern found, so restore old cursor position
       else pos=oldPos;
     }
   }
-  /* Set new text and cursor position */
+  // Set new text and cursor position
   channelInput->setText(newLine);
   channelInput->setCursorPosition(pos);
 }
@@ -467,18 +522,17 @@ void Channel::channelTextEntered()
   if(line.lower()=="/clear")
     textView->clear();
   else
-    if(line.length()) sendChannelText(line);
+    if(!line.isEmpty()) sendChannelText(line);
 
   channelInput->clear();
 }
 
 void Channel::sendChannelText(const QString& sendLine)
 {
-  QTextCodec* codec=QTextCodec::codecForName(KonversationApplication::preferences.getCodec());
-  QCString line=codec->fromUnicode(sendLine);
+  // encoding stuff is done in Server()
+  QString output=filter.parse(server->getNickname(),sendLine,getName());
 
   // Is there something we need to display for ourselves?
-  QString output=filter.parse(server->getNickname(),line,getName());
   if(!output.isEmpty())
   {
     if(filter.isAction()) appendAction(server->getNickname(),output);
@@ -491,10 +545,9 @@ void Channel::sendChannelText(const QString& sendLine)
   server->queue(filter.getServerOutput());
 }
 
-void Channel::newTextInView()
+void Channel::newTextInView(const QString& highlightColor)
 {
-  // kdDebug() << "Channel::newTextInView(): this=" << this << endl;
-  emit newText(this);
+  emit newText(this,highlightColor);
 }
 
 void Channel::setNickname(const QString& newNickname)
@@ -560,6 +613,7 @@ void Channel::addNickname(const QString& nickname,const QString& hostmask,bool o
   if(nick==0)
   {
     Nick* nick=new Nick(nicknameListView,nickname,hostmask,op,voice);
+    nicknameListView->sort();
 
     nicknameList.append(nick);
     adjustNicks(1);
@@ -598,6 +652,8 @@ void Channel::renameNick(const QString& nickname,const QString& newNick)
   Nick* nick=getNickByName(nickname);
   if(nick==0) kdWarning() << "Channel::renameNick(): Nickname " << nickname << " not found!" << endl;
   else nick->setNickname(newNick);
+
+  nicknameListView->sort();
 }
 
 void Channel::joinNickname(const QString& nickname,const QString& hostmask)
@@ -613,6 +669,7 @@ void Channel::joinNickname(const QString& nickname,const QString& hostmask)
     appendCommandMessage(i18n("Join"),i18n("%1 has joined this channel. (%2)").arg(nickname).arg(hostmask));
     addNickname(nickname,hostmask,false,false);
   }
+  nicknameListView->sort();
 }
 
 void Channel::removeNick(const QString &nickname, const QString &reason, bool quit)
@@ -717,7 +774,7 @@ void Channel::setTopic(const QString &newTopic)
     topicLine->clear();
     topicLine->insertStringList(topicHistory);
     topic=newTopic;
-    /* Add a tool tip to the topic line if it gets too long */
+    // Add a tool tip to the topic line if it gets too long
     QToolTip::remove(topicLine);
 
     if(newTopic.length()>80)
@@ -743,7 +800,7 @@ void Channel::setTopic(const QString &nickname, const QString &newTopic) // Over
   topicLine->clear();
   topicLine->insertStringList(topicHistory);
   topic=newTopic;
-  /* Add a tool tip to the topic line if it gets too long */
+  // Add a tool tip to the topic line if it gets too long
   QToolTip::remove(topicLine);
   if(newTopic.length()>80)
   {
@@ -756,6 +813,18 @@ void Channel::setTopic(const QString &nickname, const QString &newTopic) // Over
   }
 }
 
+void Channel::setTopicAuthor(const QString& newAuthor)
+{
+  if(topicAuthorUnknown)
+  {
+    kdDebug() << "adding unknown topic author " << newAuthor << endl;
+    topicHistory[0]="<"+newAuthor+"> "+topicHistory[0].section(' ',1);
+    topicLine->clear();
+    topicLine->insertStringList(topicHistory);
+    topicAuthorUnknown=false;
+  }
+}
+
 void Channel::updateMode(const QString &sourceNick, char mode, bool plus, const QString &parameter)
 {
   QString message(QString::null);
@@ -809,9 +878,12 @@ void Channel::updateMode(const QString &sourceNick, char mode, bool plus, const
       nick=getNickByName(parameter);
       if(nick)
       {
+        // Only update counter if something has actually changed
+        if(plus && !nick->isOp()) adjustOps(1);
+        else if(!plus && nick->isOp()) adjustOps(-1);
         nick->setOp(plus);
-        adjustOps((plus) ? 1 : -1);
         updateNicksOps();
+        nicknameListView->sort();
       }
     break;
 
@@ -845,7 +917,11 @@ void Channel::updateMode(const QString &sourceNick, char mode, bool plus, const
         }
       }
       nick=getNickByName(parameter);
-      if(nick) nick->setVoice(plus);
+      if(nick)
+      {
+        nick->setVoice(plus);
+        nicknameListView->sort();
+      }
     break;
 
     case 'c':
@@ -1144,16 +1220,15 @@ void Channel::updateFonts()
 
   nicksOps->setFont(KonversationApplication::preferences.getListFont());
   nicknameListView->setFont(KonversationApplication::preferences.getListFont());
+  nicknameListView->sort();
 }
 
 void Channel::openNickChangeDialog()
 {
   if(!nickChangeDialog)
   {
-    const Identity *identity=server->getIdentity();
-
     nickChangeDialog=new NickChangeDialog(this,server->getNickname(),
-                                          identity->getNicknameList(),
+                                          identity.getNicknameList(),
                                           KonversationApplication::preferences.getNicknameSize());
     connect(nickChangeDialog,SIGNAL (closeDialog(QSize)),this,SLOT (closeNickChangeDialog(QSize)) );
     connect(nickChangeDialog,SIGNAL (newNickname(const QString&)),this,SLOT (changeNickname(const QString&)) );
@@ -1175,7 +1250,7 @@ void Channel::closeNickChangeDialog(QSize newSize)
   nickChangeDialog=0;
 }
 
-QList<Nick> Channel::getNickList()
+QPtrList<Nick> Channel::getNickList()
 {
   return nicknameList;
 }
@@ -1185,4 +1260,29 @@ void Channel::adjustFocus()
   channelInput->setFocus();
 }
 
+void Channel::autoUserhost()
+{
+  int limit=5;
+
+  QString nickString;
+  QPtrList<Nick> nicks=getNickList();
+
+  for(unsigned int index=0;index<nicks.count();index++)
+  {
+    if(nicks.at(index)->getHostmask().isEmpty())
+    {
+      if(limit--) nickString=nickString+nicks.at(index)->getNickname()+" ";
+      else break;
+    }
+  }
+  if(!nickString.isEmpty()) server->requestUserhost(nickString);
+}
+
+QString Channel::getTextInLine() { return channelInput->text(); }
+
+void Channel::closeYourself()
+{
+  server->closeChannel(getName());
+}
+
 #include "channel.moc"
