@@ -11,7 +11,7 @@
     copyright: (C) 2002 by Dario Abatianni
     email:     eisfuchs@tigress.com
 
-    $Id: channel.h,v 1.27 2003/03/16 18:36:32 eisfuchs Exp $
+    $Id: channel.h,v 1.33 2003/05/13 13:32:51 eisfuchs Exp $
 */
 
 #ifndef CHANNEL_H
@@ -22,6 +22,7 @@
 #include <qcheckbox.h>
 #include <qvbox.h>
 #include <qlabel.h>
+#include <qtimer.h>
 
 #include "nick.h"
 #include "nicklistview.h"
@@ -49,27 +50,31 @@ class Channel : public ChatWindow
     void setKey(const QString& newKey);
     QString getKey();
 
-    void joinNickname(const QString &nickname,const QString &hostname);
-    void renameNick(const QString &nickname,const QString &newName);
-    void addNickname(const QString &nickname,const QString &hostmask, bool op, bool voice);
-    void removeNick(const QString &nickname, const QString &reason, bool quit);
-    void kickNick(const QString &nickname, const QString &kicker, const QString &reason);
-    Nick *getNickByName(const QString &lookname);
-    QList<Nick> getNickList();
+    void joinNickname(const QString& nickname,const QString& hostname);
+    void renameNick(const QString& nickname,const QString& newName);
+    void addNickname(const QString& nickname,const QString& hostmask, bool op, bool voice);
+    void removeNick(const QString& nickname, const QString& reason, bool quit);
+    void kickNick(const QString& nickname, const QString& kicker, const QString& reason);
+    Nick *getNickByName(const QString& lookname);
+    QPtrList<Nick> getNickList();
 
     void adjustNicks(int value);
     void adjustOps(int value);
     void updateNicksOps();
 
-    void setTopic(const QString &topic);
-    void setTopic(const QString &nickname, const QString &topic); // Overloaded
+    void setTopic(const QString& topic);
+    void setTopic(const QString& nickname,const QString& topic); // Overloaded
+    void setTopicAuthor(const QString& author);
     void updateMode(const QString &nick,char mode,bool plus, const QString &parameter);
     void updateModeWidgets(char mode, bool plus, const QString &parameter);
     void updateQuickButtons(QStringList newButtonList);
     void updateFonts();
 
+    QString getTextInLine();
+    void closeYourself();
+
   signals:
-    void newText(QWidget* channel);
+    void newText(QWidget* channel,const QString& highlightColor);
     void prefsChanged();
     void sendFile();
 
@@ -77,7 +82,7 @@ class Channel : public ChatWindow
     void setNickname(const QString& newNickname);
     void channelTextEntered();
     void sendChannelText(const QString& line);
-    void newTextInView();
+    void newTextInView(const QString& highlightColor);
     void urlCatcher(const QString &url);
     void adjustFocus();
     void showQuickButtons(bool show);
@@ -100,6 +105,7 @@ class Channel : public ChatWindow
     void textPasted(QString text);
     // connected to IRCInput::sendFile()
     void sendFileMenu();
+    void autoUserhost();
 
   protected:
     QStringList getSelectedNicksList();
@@ -113,6 +119,8 @@ class Channel : public ChatWindow
     bool modeButtonsChanged;  // to take care of redraw problem if hidden
     bool modeButtonsState;
     bool splitterChanged;
+    
+    bool topicAuthorUnknown;
 
     unsigned int completionPosition;
 
@@ -143,9 +151,10 @@ class Channel : public ChatWindow
     QCheckBox* logCheckBox;
 
     NickChangeDialog* nickChangeDialog;
-    QList<Nick> nicknameList;
+    QPtrList<Nick> nicknameList;
     QStringList selectedNicksList;
-    QList<QuickButton> buttonList;
+    QPtrList<QuickButton> buttonList;
+    QTimer userhostTimer;
 };
 
 #endif
