@@ -11,11 +11,12 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: chatwindow.cpp,v 1.29 2003/03/18 16:34:31 eisfuchs Exp $
+  $Id: chatwindow.cpp,v 1.43 2003/05/25 17:41:05 eisfuchs Exp $
 */
 
 #include <qdatetime.h>
 #include <qdir.h>
+#include <qtextcodec.h>
 
 #include <klocale.h>
 #include <kdialog.h>
@@ -23,15 +24,16 @@
 #include <krootpixmap.h>
 
 #include "server.h"
-#include "serverwindow.h"
 #include "chatwindow.h"
 #include "konversationapplication.h"
 
 ChatWindow::ChatWindow(QWidget* parent)
 {
   setName("ChatWindowObject");
+
   parentWidget=parent;
   firstLog=true;
+  server=0;
 
   setMargin(margin());
   setSpacing(spacing());
@@ -44,10 +46,11 @@ ChatWindow::~ChatWindow()
 {
 }
 
-void ChatWindow::setName(QString newName)
+void ChatWindow::setName(const QString& newName)
 {
   name=newName;
   scriptLauncher.setTargetName(newName);
+  emit nameChanged(this,newName);
 }
 
 QString& ChatWindow::getName()
@@ -72,45 +75,61 @@ void ChatWindow::setServer(Server* newServer)
   {
     server=newServer;
 
-    if(textView) textView->setServer(newServer);
-    else kdDebug() << "ChatWindow::setServer(): textView==0!" << endl;
-  
-    connect(&filter,SIGNAL (openQuery(const QString&,const QString&)),
-             server,SLOT   (addQuery(const QString&,const QString&)) );
-    connect(&filter,SIGNAL (openDccPanel()),
-             server,SLOT   (requestDccPanel()) );
-    connect(&filter,SIGNAL (closeDccPanel()),
-             server,SLOT   (requestCloseDccPanel()) );
-    connect(&filter,SIGNAL (openDccSend(const QString &, const QString &)),
-             server,SLOT   (addDccSend(const QString &, const QString &)) );
-    connect(&filter,SIGNAL (requestDccSend()),
-             server,SLOT   (requestDccSend()) );
-    connect(&filter,SIGNAL (requestDccSend(const QString &)),
-             server,SLOT   (requestDccSend(const QString &)) );
-    connect(&filter,SIGNAL (away()),
-             server,SLOT   (away()) );
-    connect(&filter,SIGNAL (unAway()),
-             server,SLOT   (unAway()) );
-    connect(&filter,SIGNAL (sendToAllChannels(const QString&)),
-             server,SLOT   (sendToAllChannels(const QString&)) );
+    // check if we need to set up the signals
+    if(getType()!=ChannelList)
+    {
+      if(textView) textView->setServer(newServer);
+      else kdDebug() << "ChatWindow::setServer(): textView==0!" << endl;
 
-    connect(&filter,SIGNAL (openRawLog()), server,SLOT (addRawLog()) );
-    connect(&filter,SIGNAL (closeRawLog()),server,SLOT (closeRawLog()) );
-    
-    scriptLauncher.setServerName(server->getServerName());
+      connect(&filter,SIGNAL (openQuery(const QString&,const QString&)),
+               server,SLOT   (addQuery(const QString&,const QString&)) );
 
-    connect(&scriptLauncher,SIGNAL (scriptNotFound(const QString&)),
-                       server,SLOT (scriptNotFound(const QString&)) );
-    connect(&scriptLauncher,SIGNAL (scriptExecutionError(const QString&)),
-                       server,SLOT (scriptExecutionError(const QString&)) );
+      connect(&filter,SIGNAL (openDccPanel()),
+               server,SLOT   (requestDccPanel()) );
+      connect(&filter,SIGNAL (closeDccPanel()),
+               server,SLOT   (requestCloseDccPanel()) );
+      connect(&filter,SIGNAL (openDccSend(const QString &, const QString &)),
+               server,SLOT   (addDccSend(const QString &, const QString &)) );
+      connect(&filter,SIGNAL (requestDccSend()),
+               server,SLOT   (requestDccSend()) );
+      connect(&filter,SIGNAL (requestDccSend(const QString &)),
+               server,SLOT   (requestDccSend(const QString &)) );
 
+      connect(&filter,SIGNAL (openKonsolePanel()),
+               server,SLOT   (requestKonsolePanel()) );
+
+      connect(&filter,SIGNAL (away()),
+               server,SLOT   (away()) );
+      connect(&filter,SIGNAL (unAway()),
+               server,SLOT   (unAway()) );
+
+      connect(&filter,SIGNAL (sendToAllChannels(const QString&)),
+               server,SLOT   (sendToAllChannels(const QString&)) );
+      connect(&filter,SIGNAL (banUsers(const QStringList&,const QString&,const QString&)),
+               server,SLOT   (requestBan(const QStringList&,const QString&,const QString&)) );
+
+      connect(&filter,SIGNAL (openRawLog(bool)), server,SLOT (addRawLog(bool)) );
+      connect(&filter,SIGNAL (closeRawLog()),server,SLOT (closeRawLog()) );
+
+      scriptLauncher.setServerName(server->getServerName());
+
+      connect(&scriptLauncher,SIGNAL (scriptNotFound(const QString&)),
+                         server,SLOT (scriptNotFound(const QString&)) );
+      connect(&scriptLauncher,SIGNAL (scriptExecutionError(const QString&)),
+                         server,SLOT (scriptExecutionError(const QString&)) );
+    }
   }
 }
 
+Server* ChatWindow::getServer()
+{
+  return server;
+}
+
 void ChatWindow::setIdentity(const Identity *newIdentity)
 {
-  identity=newIdentity;
-  filter.setIdentity(identity);
+  identity=*newIdentity;
+  filter.setIdentity(newIdentity);
 }
 
 void ChatWindow::setTextView(IRCView* newView)
@@ -119,37 +138,37 @@ void ChatWindow::setTextView(IRCView* newView)
   connect(textView,SIGNAL (textToLog(const QString&)),this,SLOT (logText(const QString&)) );
 }
 
-void ChatWindow::appendRaw(const char* message)
+void ChatWindow::appendRaw(const QString& message)
 {
   textView->appendRaw(message);
 }
 
-void ChatWindow::append(const char* nickname,const char* message)
+void ChatWindow::append(const QString& nickname,const QString& message)
 {
   textView->append(nickname,message);
 }
 
-void ChatWindow::appendQuery(const char* nickname,const char* message)
+void ChatWindow::appendQuery(const QString& nickname,const QString& message)
 {
   textView->appendQuery(nickname,message);
 }
 
-void ChatWindow::appendAction(const char* nickname,const char* message)
+void ChatWindow::appendAction(const QString& nickname,const QString& message)
 {
   textView->appendAction(nickname,message);
 }
 
-void ChatWindow::appendServerMessage(const char* type,const char* message)
+void ChatWindow::appendServerMessage(const QString& type,const QString& message)
 {
   textView->appendServerMessage(type,message);
 }
 
-void ChatWindow::appendCommandMessage(const char* command,const char* message)
+void ChatWindow::appendCommandMessage(const QString& command,const QString& message)
 {
   textView->appendCommandMessage(command,message);
 }
 
-void ChatWindow::appendBacklogMessage(const char* firstColumn,const char* message)
+void ChatWindow::appendBacklogMessage(const QString& firstColumn,const QString& message)
 {
   textView->appendBacklogMessage(firstColumn,message);
 }
@@ -188,22 +207,26 @@ void ChatWindow::setLogfileName(const QString& name)
       unsigned long filePosition;
 
       QString backlogLine;
+      QTextStream backlog(&logfile);
+      backlog.setEncoding(QTextStream::UnicodeUTF8);
       // Set file pointer to 1 kB from the end
-      logfile.at(logfile.size()-1024);
+      backlog.device()->at(backlog.device()->size()-1024);
       // Skip first line, since it may be incomplete
-      logfile.readLine(backlogLine,1024);
+      backlog.readLine();
+       
       // Loop until end of file reached
-      while(!logfile.atEnd())
+      while(!backlog.atEnd())
       {
         // remember actual file position to check for deadlocks
-        filePosition=logfile.at();
+        filePosition=backlog.device()->at();
 
-        logfile.readLine(backlogLine,1024);
+        backlogLine=backlog.readLine();
+         
         // check for deadlocks
-        if(logfile.at()==filePosition) logfile.at(filePosition+1);
-        // if a tab character is present in the line
-        if(backlogLine.find('\t')!=-1)
-        {
+        if(backlog.device()->at()==filePosition) backlog.device()->at(filePosition+1);
+         // if a tab character is present in the line
+         if(backlogLine.find('\t')!=-1)
+         {
           // extract timestamp from log
           QString backlogTime=backlogLine.left(backlogLine.find(' '));
           // cut timestamp from line
@@ -212,10 +235,12 @@ void ChatWindow::setLogfileName(const QString& name)
           QString backlogFirst=backlogLine.left(backlogLine.find('\t'));
           // cut first column from line
           backlogLine=backlogLine.mid(backlogLine.find('\t')+1);
+          // Logfile is in utf8 so we don't need to do encoding stuff here
           // append backlog with time and first column to text view
           appendBacklogMessage(backlogFirst,backlogTime+' '+backlogLine);
         }
       } // while
+      backlog.unsetDevice();
       logfile.close();
     }
   }
@@ -230,16 +255,27 @@ void ChatWindow::logText(const QString& text)
 
     if(logfile.open(IO_WriteOnly | IO_Append))
     {
+      // wrap the file into a stream
+      QTextStream logStream(&logfile);
+      // write log in utf8 to help i18n
+      logStream.setEncoding(QTextStream::UnicodeUTF8);
+
       if(firstLog)
       {
         QString intro(i18n("\n*** Logfile started\n*** on %1\n\n").arg(QDateTime::currentDateTime().toString()));
-        logfile.writeBlock(intro,intro.length());
+        logStream << intro;
         firstLog=false;
       }
 
       QTime time=QTime::currentTime();
       QString logLine(QString("[%1] %2\n").arg(time.toString("hh:mm:ss")).arg(text));
-      logfile.writeBlock(logLine,logLine.length());
+
+      logStream << logLine;
+
+      // detach stream from file
+      logStream.unsetDevice();
+
+      // close file
       logfile.close();
     }
     else kdWarning() << "ChatWindow::logText(): open(IO_Append) for " << logfile.name() << " failed!" << endl;
@@ -267,4 +303,12 @@ int ChatWindow::margin()
 IRCView* ChatWindow::getTextView()     { return textView; }
 void ChatWindow::setLog(bool activate) { log=activate; }
 
+// reimplement this in all panels that have user input
+QString ChatWindow::getTextInLine() { return QString::null; }
+
+// reimplement this if your window needs special close treatment
+void ChatWindow::closeYourself()
+{
+}
+
 #include "chatwindow.moc"
