@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: chatwindow.h,v 1.12 2003/03/18 14:34:57 eisfuchs Exp $
+  $Id: chatwindow.h,v 1.18 2003/05/18 22:58:45 eisfuchs Exp $
 */
 
 #ifndef CHATWINDOW_H
@@ -48,31 +48,40 @@ class ChatWindow : public QVBox
       DccPanel,
       RawLog,
       Notice,
-      SNotice
+      SNotice,
+      ChannelList,
+      Konsole
     };
 
     void setServer(Server* newServer);
+    Server* getServer();
     void setIdentity(const Identity *newIdentity);
     void setTextView(IRCView* newView);
     IRCView* getTextView();
     void setLog(bool activate);
 
-    void setName(QString newName);
+    void setName(const QString& newName);
     QString& getName();
 
     void setType(WindowType newType);
     WindowType getType();
 
-    void append(const char* nickname,const char* message);
-    void appendRaw(const char* message);
-    void appendQuery(const char* nickname,const char* message);
-    void appendAction(const char* nickname,const char* message);
-    void appendServerMessage(const char* type,const char* message);
-    void appendCommandMessage(const char* command,const char* message);
-    void appendBacklogMessage(const char* firstColumn,const char* message);
+    void append(const QString& nickname,const QString& message);
+    void appendRaw(const QString& message);
+    void appendQuery(const QString& nickname,const QString& message);
+    void appendAction(const QString& nickname,const QString& message);
+    void appendServerMessage(const QString& type,const QString& message);
+    void appendCommandMessage(const QString& command,const QString& message);
+    void appendBacklogMessage(const QString& firstColumn,const QString& message);
 
     QWidget* parentWidget;
 
+    virtual QString getTextInLine();
+    virtual void closeYourself();
+
+  signals:
+    void nameChanged(ChatWindow* view,const QString& newName);
+
   public slots:
     void logText(const QString& text);
     virtual void adjustFocus() = 0;
@@ -93,7 +102,7 @@ class ChatWindow : public QVBox
 
     IRCView* textView;
     Server* server;
-    const Identity *identity;
+    Identity identity;
     QFile logfile;
     OutputFilter filter;
     WindowType type;
