@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: dccpanel.cpp,v 1.20 2003/03/19 22:54:51 eisfuchs Exp $
+  $Id: dccpanel.cpp,v 1.26 2003/05/25 17:41:05 eisfuchs Exp $
 */
 
 #include <qhbox.h>
@@ -48,7 +48,6 @@ DccPanel::DccPanel(QWidget* parent) :
   QHBox* buttonsBox=new QHBox(this);
   buttonsBox->setSpacing(spacing());
   acceptButton=new QPushButton(i18n("Accept"),buttonsBox,"start_dcc");
-  sendButton  =new QPushButton(i18n("Send File"),buttonsBox,"send_dcc");
   abortButton =new QPushButton(i18n("Abort"),buttonsBox,"abort_dcc");
   removeButton=new QPushButton(i18n("Remove"),buttonsBox,"remove_dcc");
   openButton  =new QPushButton(i18n("Open"),buttonsBox,"open_dcc_file");
@@ -57,7 +56,6 @@ DccPanel::DccPanel(QWidget* parent) :
   connect(dccListView,SIGNAL (selectionChanged()),this,SLOT (dccSelected()) );
 
   connect(acceptButton,SIGNAL (clicked()) ,this,SLOT (acceptDcc()) );
-  connect(sendButton,SIGNAL (clicked()) ,this,SLOT (sendDcc()) );
   connect(abortButton,SIGNAL (clicked()) ,this,SLOT (abortDcc()) );
   connect(removeButton,SIGNAL (clicked()) ,this,SLOT (removeDcc()) );
   connect(openButton,SIGNAL (clicked()) ,this,SLOT (runDcc()) );
@@ -78,8 +76,7 @@ void DccPanel::setButtons(bool accept,bool abort,bool remove,bool open,bool info
 
 void DccPanel::dccSelected()
 {
-  DccTransfer* item=(DccTransfer*) getListView()->selectedItem();
-  kdDebug() << "(item)" << item << endl;
+  DccTransfer* item=static_cast<DccTransfer*>(getListView()->selectedItem());
 
   if(item)
   {
@@ -89,7 +86,7 @@ void DccPanel::dccSelected()
       case DccTransfer::Queued:
       case DccTransfer::Lookup:
       case DccTransfer::Connecting:
-        setButtons(true,false,true,false,false);
+        setButtons(true,true,true,false,false);
         break;
       case DccTransfer::Offering:
       case DccTransfer::Resuming:
@@ -121,11 +118,6 @@ void DccPanel::acceptDcc()
   }
 }
 
-void DccPanel::sendDcc()
-{
- emit requestDccSend();
-}
-
 void DccPanel::runDcc()
 {
   DccTransfer* item=static_cast<DccTransfer*>(getListView()->selectedItem());
@@ -141,12 +133,12 @@ void DccPanel::runDcc()
 void DccPanel::abortDcc()
 {
   DccTransfer* item=static_cast<DccTransfer*>(getListView()->selectedItem());
-  item->abort();
+  if(item) item->abort();
 }
 
 void DccPanel::removeDcc()
 {
-  DccTransfer* item=(DccTransfer*) getListView()->selectedItem();
+  DccTransfer* item=static_cast<DccTransfer*>(getListView()->selectedItem());
 
   if(item)
   {
@@ -163,7 +155,13 @@ void DccPanel::removeDcc()
       doDelete=false;
     }
 
-    if(doDelete) delete item;
+    if(doDelete)
+    {
+      delete item;
+      // select next item so the user can clean up the list quickly
+      item=static_cast<DccTransfer*>(getListView()->currentItem());
+      if(item) getListView()->setSelected(item,true);
+    }
   }
 }
 
@@ -174,10 +172,9 @@ DccTransfer* DccPanel::getTransferByPort(QString port,DccTransfer::DccType type)
   do
   {
     // TODO: Get rid of this cast
-    item=(DccTransfer*) getListView()->itemAtIndex(index++);
+    item=static_cast<DccTransfer*>(getListView()->itemAtIndex(index++));
     if(item)
     {
-      kdDebug() << item->getType() << endl;
       if(item->getStatus()<DccTransfer::Failed &&
          item->getType()==type &&
          item->getPort()==port) return item;
@@ -194,10 +191,9 @@ DccTransfer* DccPanel::getTransferByName(QString name,DccTransfer::DccType type)
   do
   {
     // TODO: Get rid of this cast
-    item=(DccTransfer*) getListView()->itemAtIndex(index++);
+    item=static_cast<DccTransfer*>(getListView()->itemAtIndex(index++));
     if(item)
     {
-      kdDebug() << name << " == " << item->getFile() << endl;
       if(item->getStatus()<DccTransfer::Failed &&
          item->getType()==type &&
          item->getFile()==name) return item;
