@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: dccpanel.h,v 1.11 2003/03/02 12:01:21 eisfuchs Exp $
+  $Id: dccpanel.h,v 1.13 2003/04/25 13:22:47 eisfuchs Exp $
 */
 
 #ifndef DCCPANEL_H
@@ -39,17 +39,13 @@ class DccPanel : public ChatWindow
     KListView* getListView();
     DccTransfer* getTransferByPort(QString port,DccTransfer::DccType type);
     DccTransfer* getTransferByName(QString name,DccTransfer::DccType type);
-
-  signals:
-    void requestDccSend();
-
+  
   public slots:
     void adjustFocus();
-    
+
   protected slots:
     void acceptDcc();
     void runDcc();
-    void sendDcc();
     void abortDcc();
     void removeDcc();
     void dccSelected();
@@ -60,7 +56,6 @@ class DccPanel : public ChatWindow
     KListView* dccListView;
 
     QPushButton* acceptButton;
-    QPushButton* sendButton;
     QPushButton* abortButton;
     QPushButton* removeButton;
     QPushButton* openButton;
