@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: dccrecipientdialog.cpp,v 1.7 2003/03/23 14:33:30 eisfuchs Exp $
+  $Id: dccrecipientdialog.cpp,v 1.8 2003/04/24 22:51:50 eisfuchs Exp $
 */
 
 #include <qlayout.h>
@@ -41,7 +41,10 @@ DccRecipientDialog::DccRecipientDialog(QWidget* parent,QStringList list,QSize si
   nicknameList->insertStringList(list);
   nicknameList->sort(true);
 
+  nicknameInput=new KLineEdit(page,"nickname_input");
+  
   dialogLayout->addWidget(nicknameList);
+  dialogLayout->addWidget(nicknameInput);
 
   connect(nicknameList,SIGNAL (highlighted(QListBoxItem*)),this,SLOT (newNicknameSelected(QListBoxItem*)) );
   connect(nicknameList,SIGNAL (doubleClicked(QListBoxItem*)),this,SLOT (newNicknameSelectedQuit(QListBoxItem*)) );
@@ -65,12 +68,14 @@ QString DccRecipientDialog::getSelectedNickname()
 
 void DccRecipientDialog::newNicknameSelected(QListBoxItem* item)
 {
-  selectedNickname=item->text();
+  nicknameInput->setText(item->text());
 }
 
 void DccRecipientDialog::newNicknameSelectedQuit(QListBoxItem* item)
 {
-  selectedNickname=item->text();
+  newNicknameSelected(item);
+  selectedNickname=nicknameInput->text();
+  
   delayedDestruct();
 }
 
@@ -80,6 +85,12 @@ void DccRecipientDialog::slotCancel()
   KDialogBase::slotCancel();
 }
 
+void DccRecipientDialog::slotOk()
+{
+  selectedNickname=nicknameInput->text();
+  KDialogBase::slotOk();
+}
+
 QString DccRecipientDialog::getNickname(QWidget* parent,QStringList list)
 {
   kdDebug() << "DccRecipientDialog::getNickname()" << endl;
