@@ -11,13 +11,14 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: dccrecipientdialog.h,v 1.2 2003/02/15 19:24:17 eisfuchs Exp $
+  $Id: dccrecipientdialog.h,v 1.3 2003/04/24 22:51:50 eisfuchs Exp $
 */
 
 #ifndef DCCRECIPIENTDIALOG_H
 #define DCCRECIPIENTDIALOG_H
 
 #include <kdialogbase.h>
+#include <klineedit.h>
 
 /*
   @author Dario Abatianni
@@ -37,12 +38,14 @@ class DccRecipientDialog : public KDialogBase
     void newNicknameSelected(QListBoxItem* item);
     void newNicknameSelectedQuit(QListBoxItem* item);  // KDE double click
 
+    void slotOk();
     void slotCancel();
 
-  protected:
+  protected:  
     QString getSelectedNickname();
     static QString selectedNickname;
 
+    KLineEdit* nicknameInput;
 };
 
 #endif
