@@ -11,9 +11,11 @@
   copyright: (C) 2003 by Dario Abatianni
   email: eisfuchs@tigress.com
 
-  $Id: identity.cpp,v 1.5 2003/03/13 18:59:15 eisfuchs Exp $
+  $Id: identity.cpp,v 1.6 2003/05/09 12:25:53 eisfuchs Exp $
 */
 
+#include <kdebug.h>
+
 #include "identity.h"
 
 Identity::Identity()
@@ -26,6 +28,7 @@ Identity::Identity()
 
 Identity::~Identity()
 {
+  kdDebug() << "Identity::~Identity("+getName()+")" << endl;
 }
 
 void Identity::setName(const QString& newName)          { name=newName; }
