@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: ignore.h,v 1.3 2003/02/02 23:41:33 eisfuchs Exp $
+  $Id: ignore.h,v 1.4 2003/04/24 22:51:50 eisfuchs Exp $
 */
 
 #ifndef IGNORE_H
@@ -39,10 +39,10 @@ class Ignore
     Ignore(QString name,int flags);
     ~Ignore();
 
-    void setName(QString newName) { name=newName; };
-    void setFlags(int newFlags) { flags=newFlags; };
-    QString getName() { return name; };
-    int getFlags() { return flags; };
+    void setName(QString newName);
+    void setFlags(int newFlags);
+    QString getName();
+    int getFlags();
 
   protected:
     QString name;
