@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: ignoredialog.cpp,v 1.8 2003/03/23 14:33:30 eisfuchs Exp $
+  $Id: ignoredialog.cpp,v 1.9 2003/05/12 11:59:42 eisfuchs Exp $
 */
 
 #include <qlayout.h>
@@ -28,7 +28,7 @@
 #include "ignoredialog.h"
 
 IgnoreDialog::IgnoreDialog(QPtrList<Ignore> newIgnoreList,QSize newSize):
-               KDialogBase(0,"ignoredialog",false,i18n("Edit ignore list"),
+               KDialogBase(static_cast<QWidget*>(0),"ignoredialog",false,i18n("Edit ignore list"),
                            KDialogBase::Ok | KDialogBase::Apply | KDialogBase::Cancel,
                            KDialogBase::Ok,true)
 {
