@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
  
-  $Id: inputfilter.cpp,v 1.43 2003/03/19 16:14:44 eisfuchs Exp $
+  $Id: inputfilter.cpp,v 1.54 2003/05/24 10:42:45 eisfuchs Exp $
 */
 
 #include <qdatastream.h>
@@ -25,13 +25,14 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #else
-#define VERSION "$Id: inputfilter.cpp,v 1.43 2003/03/19 16:14:44 eisfuchs Exp $"
+#define VERSION 0.12
 #endif
 
 #include "inputfilter.h"
 #include "server.h"
 #include "errorcodes.h"
 #include "konversationapplication.h"
+#include "commit.h"
 
 #if QT_VERSION < 0x030100
 #include "main.h"
@@ -41,6 +42,7 @@ InputFilter::InputFilter()
 {
   kdDebug() << "InputFilter::InputFilter()" << endl;
   welcomeSent=false;
+  automaticRequest=0;
 }
 
 InputFilter::~InputFilter()
@@ -116,6 +118,9 @@ void InputFilter::parseClientCommand(const QString &prefix, const QString &comma
   // Extract nickname fron prefix
   QString sourceNick=prefix.left(prefix.find("!"));
   QString sourceHostmask=prefix.mid(prefix.find("!")+1);
+          
+  // remember hostmask for this nick, it could have changed
+  server->addHostmaskToNick(sourceNick,sourceHostmask);
 
   if(command=="privmsg")
   {
@@ -164,15 +169,9 @@ void InputFilter::parseClientCommand(const QString &prefix, const QString &comma
         // Check if we ignore queries from this nick
         if(!isIgnore(prefix,Ignore::Query))
         {
-          // Check if this nick is already in a query with us
-          Query* query=server->getQueryByName(sourceNick);
-          // If not, create a new one
-          if(!query)
-            server->addQuery(sourceNick,sourceHostmask);
-          // else remember hostmask for this nick, it could have changed
-          else
-            server->addHostmaskToNick(sourceNick,sourceHostmask);
-
+          // create new query (server will check for dupes)
+          server->addQuery(sourceNick,sourceHostmask);
+          // send action to query
           server->appendActionToQuery(sourceNick,ctcpArgument);
         }
       }
@@ -199,7 +198,10 @@ void InputFilter::parseClientCommand(const QString &prefix, const QString &comma
             server->appendStatusMessage(i18n("CTCP"),i18n("Received Version request from %1 to channel %2.").arg(sourceNick).arg(parameterList[0]));
           else
             server->appendStatusMessage(i18n("CTCP"),i18n("Received Version request from %1.").arg(sourceNick));
-          server->ctcpReply(sourceNick,QString("VERSION Konversation %1 (C)2002-2003 Dario Abatianni and Matthias Gierlings").arg(VERSION));
+
+          server->ctcpReply(sourceNick,QString("VERSION Konversation %1 (C)2002-2003 by the Konversation team").arg(QString(VERSION)+QString(" Build %1").arg(COMMIT)));
+// TODO: Switch here when i18n-freeze is over
+//          server->ctcpReply(sourceNick,QString("VERSION Konversation %1 Build %2 (C)2002-2003 by the Konversation team").arg(QString(VERSION)).arg(COMMIT)));
         }
       }
       // DCC request?
@@ -284,8 +286,6 @@ void InputFilter::parseClientCommand(const QString &prefix, const QString &comma
         {
           // Create a new query (server will check for dupes)
           server->addQuery(sourceNick,sourceHostmask);
-          // else remember hostmask for this nick, it could have changed
-          server->addHostmaskToNick(sourceNick,sourceHostmask);
           // Append this message to the query
           server->appendToQuery(sourceNick,trailing);
         }
@@ -554,9 +554,7 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
     {
       QString text;
       text=(trailing.length()) ? trailing : parameterList.join(" ");
-      text=":"+text;
-      if(prefix.length())
-        text=prefix+" "+text;
+      if(prefix.length()) text=prefix+" :"+text;
       server->queue("PONG "+text);
     }
     else if(command=="error :closing link:")
@@ -761,6 +759,7 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
           QDateTime when;
           when.setTime_t(parameterList[3].toUInt());
           server->appendCommandMessageToChannel(parameterList[1],i18n("Topic"),i18n("Topic was set by %1 on %2.").arg(parameterList[2]).arg(when.toString(Qt::LocalDate)));
+          emit topicAuthor(parameterList[1],parameterList[2]);
           break;
         }
       case ERR_NOSUCHNICK:
@@ -908,10 +907,85 @@ void InputFilter::parseServerCommand(const QString &prefix, const QString &comma
           server->appendStatusMessage(i18n("Whois"),i18n("End of WHOIS list."));
           break;
         }
+      case RPL_USERHOST:
+        {
+          // iterate over all nick/masks in reply
+          QStringList uhosts=QStringList::split(" ",trailing);
+
+          for(unsigned int index=0;index<uhosts.count();index++)
+          {
+            // extract nickname and hostmask from reply
+            QString nick(uhosts[index].section('=',0,0));
+            QString mask(uhosts[index].section('=',1));
+
+            // get away and IRC operator flags
+            bool away=(mask[0]=='-');
+            bool ircOp=(nick[nick.length()-1]=='*');
+
+            // cut flags from nick/hostmask
+            mask=mask.mid(1);
+            if(ircOp) nick=nick.left(nick.length()-1);
+
+            // inform serer of this user's data
+            emit userhost(nick,mask,away,ircOp);
+
+            // display message only if this was no automatic request
+            if(getAutomaticRequest()==0)
+            {
+              server->appendStatusMessage(i18n("Userhost"),
+                                          i18n("%1%2 is %3%4")
+                                               .arg(nick)
+                                               .arg((ircOp) ? i18n(" (IRC Operator)") : QString::null)
+                                               .arg(mask)
+                                               .arg((away) ? i18n(" (away)") : QString::null));
+            }
+          } // for
+
+          // was this an automatic request?
+          if(getAutomaticRequest()!=0) setAutomaticRequest(false);
+
+          break;
+        }
+      case RPL_LISTSTART:
+        {
+          if(getAutomaticRequest()==0)
+          {
+            server->appendStatusMessage(i18n("List"),i18n("List of channels:"));
+          }
+          else emit addChannelListPanel();
+          break;
+        }
+      case RPL_LIST:
+        {
+          if(getAutomaticRequest()==0)
+          {
+            QString message;
+          
+            if(parameterList[2]=="1") message=i18n("%1 (%2 user): %3");
+            else message=i18n("%1 (%2 users): %3");
+          
+            server->appendStatusMessage(i18n("List"),message.arg(parameterList[1]).arg(parameterList[2]).arg(trailing));
+          }
+          else // send them to /LIST window
+            emit addToChannelList(parameterList[1],parameterList[2].toInt(),trailing);
+          
+          break;
+        }
+      case RPL_LISTEND:
+        {
+          // was this an automatic request?
+          if(getAutomaticRequest()==0)
+            server->appendStatusMessage(i18n("List"),i18n("End of channel list."));
+          else
+            setAutomaticRequest(false);
+          
+          break;
+        }
       default:
         {
-          // All yet unknown messages go into the frontmost window unaltered
-          server->appendStatusMessage(command,parameterList.join(" ")+" "+trailing);
+          // All yet unknown messages go into the frontmost window without the
+          // preceeding nickname
+          server->appendStatusMessage(command,parameterList.join(" ").section(' ',1)+" "+trailing);
         }
     }
   }
@@ -981,4 +1055,15 @@ bool InputFilter::isIgnore(const QString &sender, Ignore::Type type)
   return doIgnore;
 }
 
+void InputFilter::setAutomaticRequest(bool yes)
+{
+  automaticRequest+=(yes) ? 1 : -1;
+  if(automaticRequest<0)
+  {
+    kdDebug() << "InputFilter::automaticRequest was negative! Resetting!" << endl;
+    automaticRequest=0;
+  }
+}
+int InputFilter::getAutomaticRequest() { return automaticRequest; }
+
 #include "inputfilter.moc"
