@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: ircinput.cpp,v 1.14 2003/03/20 13:51:48 eisfuchs Exp $
+  $Id: ircinput.cpp,v 1.20 2003/04/16 12:56:05 eisfuchs Exp $
 */
 
 #include <kdebug.h>
@@ -20,6 +20,7 @@
 #include <klocale.h>
 
 #include <qclipboard.h>
+#include <qregexp.h>
 
 #include "ircinput.h"
 
@@ -88,6 +89,8 @@ bool IRCInput::eventFilter(QObject *object,QEvent *event)
           if(!keyEvent->text().isEmpty()) setCompletionMode('\0');
           // support ASCII BEL
           if(keyEvent->ascii()==7) insert("%G");
+          // support ^U (delete text in input box)
+          if(keyEvent->ascii()==21) clear();
           // support ^W (delete word)
           else if(keyEvent->ascii()==23)
           {
@@ -123,6 +126,8 @@ void IRCInput::addHistory(const QString& line)
 
 void IRCInput::getHistory(bool up)
 {
+  // preserve text
+  historyList[lineNum]=text();
   // Did the user press cursor up?
   if(up)
   {
@@ -146,11 +151,17 @@ void IRCInput::paste()
   QClipboard *cb=KApplication::kApplication()->clipboard();
 
   // Copy text from the clipboard (paste)
+#if QT_VERSION >= 0x030100
+  QString text=cb->text(QClipboard::Selection);
+#else
   QString text=cb->text();
+#endif
   // is there any text in the clipboard?
   if(!text.isEmpty())
   {
     bool signal=false;
+    // replace \r with \n to make xterm pastes happy
+    text.replace(QRegExp("\r"),"\n");
     // does the text contain at least one newline character?
     if(text.find('\n')!=-1)
     {
@@ -168,7 +179,7 @@ void IRCInput::paste()
     {
       int doPaste=KMessageBox::Yes;
 
-      if(text.length()>512)
+      if(text.length()>256 || text.contains('\n')>2)
       {
         doPaste=KMessageBox::warningYesNo
                 (
