@@ -11,7 +11,7 @@
   copyright: (C) 2003 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: ircresolver.h,v 1.3 2003/03/06 15:06:07 eisfuchs Exp $
+  $Id: ircresolver.h,v 1.4 2003/04/24 22:51:50 eisfuchs Exp $
 */
 
 
@@ -21,11 +21,10 @@
 #include <qthread.h>
 #include <qmutex.h>
 
-#include <kextendedsocket.h>
-
 /*
   @author Dario Abatianni
 */
+class KExtendedSocket;
 
 class IRCResolver : public QThread
 {
