@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: ircserversocket.cpp,v 1.6 2003/02/27 13:50:32 eisfuchs Exp $
+  $Id: ircserversocket.cpp,v 1.7 2003/05/12 11:59:43 eisfuchs Exp $
 */
 
 #include "ircserversocket.h"
@@ -28,7 +28,7 @@ IRCServerSocket::IRCServerSocket(const char *server,unsigned short int port,int
                  KExtendedSocket(server,port,KExtendedSocket::inetSocket)
 {
   setTimeout(timeout);
-  kdDebug() << "IRCServerSocket::IRCServerSocket(" << server << "," << port << ")" << endl;
+  kdDebug() << "IRCServerSocket::IRCServerSocket(" << server << "," << port << "," << timeout << ")" << endl;
 }
 
 IRCServerSocket::~IRCServerSocket()
