@@ -11,17 +11,17 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: ircview.cpp,v 1.57 2003/03/18 14:34:57 eisfuchs Exp $
+  $Id: ircview.cpp,v 1.71 2003/05/11 23:12:12 eisfuchs Exp $
 */
 
 // Comment this #define to try a different text widget
 // #define TABLE_VERSION
 
 #include <qstylesheet.h>
-#include <qtextcodec.h>
 #include <qstringlist.h>
 #include <qregexp.h>
 #include <qtextbrowser.h>
+#include <qclipboard.h>
 
 // Check if we use special QT versions to keep text widget from displaying
 // all lines after another without line breaks
@@ -42,16 +42,20 @@ IRCView::IRCView(QWidget* parent,Server* newServer) : KTextBrowser(parent)
 {
   kdDebug() << "IRCView::IRCView()" << endl;
 
+  highlightColor=QString::null;
+  copyUrlMenu=false;
+  urlToCopy=QString::null;
+
   popup=new QPopupMenu(this,"ircview_context_menu");
 
   if(popup)
   {
     popup->insertItem(i18n("&Copy"),Copy);
-    popup->insertItem(i18n("Select All"),SelectAll);
+    popup->insertItem(i18n("Select all"),SelectAll);
     popup->insertSeparator();
     popup->insertItem(i18n("Search text"),Search);
     popup->insertSeparator();
-    popup->insertItem(i18n("Send File"),SendFile);
+    popup->insertItem(i18n("Send file"),SendFile);
   }
   else kdWarning() << "IRCView::IRCView(): Could not create popup!" << endl;
 
@@ -63,6 +67,22 @@ IRCView::IRCView(QWidget* parent,Server* newServer) : KTextBrowser(parent)
 
   installEventFilter(this);
 
+  // set style sheet for <p> to define paragraph spacing
+  QStyleSheet* sheet=new QStyleSheet(this,"ircview_style_sheet");
+
+  int paragraphSpacing;
+  if(KonversationApplication::preferences.getUseParagraphSpacing())
+    paragraphSpacing=KonversationApplication::preferences.getParagraphSpacing();
+  else
+    paragraphSpacing=0;
+
+  QStyleSheetItem* style=new QStyleSheetItem(sheet,"p");
+  style->setDisplayMode(QStyleSheetItem::DisplayBlock);
+  style->setMargin(QStyleSheetItem::MarginVertical,paragraphSpacing);
+  style->setSelfNesting(false);
+
+  setStyleSheet(sheet);
+
   setServer(newServer);
   setFont(KonversationApplication::preferences.getTextFont());
 
@@ -81,6 +101,7 @@ IRCView::IRCView(QWidget* parent,Server* newServer) : KTextBrowser(parent)
 #ifndef TABLE_VERSION
   setText("<qt>\n");
 #endif
+  connect(this,SIGNAL (highlighted(const QString&)),this,SLOT (highlightedSlot(const QString&)));
 }
 
 IRCView::~IRCView()
@@ -101,6 +122,21 @@ void IRCView::clear()
   KTextBrowser::clear();
 }
 
+void IRCView::highlightedSlot(const QString& link)
+{
+  if(link.isEmpty() && copyUrlMenu)
+  {
+    popup->removeItem(CopyUrl);
+    copyUrlMenu=false;
+  }
+  else if(!link.isEmpty() && !copyUrlMenu)
+  {
+    popup->insertItem(i18n("Copy URL to clipboard"),CopyUrl,1);
+    copyUrlMenu=true;
+    urlToCopy=link;
+  }
+}
+
 void IRCView::replaceDecoration(QString& line,char decoration,char replacement)
 {
   int pos;
@@ -117,15 +153,6 @@ QString IRCView::filter(const QString& line,const QString& whoSent,bool doHiligh
 {
   QString filteredLine(line);
 
-  // make sure that own lines don't always get highlight
-  QString who;
-
-  // FIXME: We got to get rid of server dependance here
-  if(server)
-  {
-    if(whoSent!=server->getNickname() || KonversationApplication::preferences.getHilightOwnLines()) who=whoSent;
-  }
-
   // TODO: Use QStyleSheet::escape() here
 
   // Replace all & with &amp;
@@ -134,8 +161,10 @@ QString IRCView::filter(const QString& line,const QString& whoSent,bool doHiligh
   filteredLine.replace(QRegExp("\\<"),"&lt;");
   // Replace all > with &gt;
   filteredLine.replace(QRegExp("\\>"),"&gt;");
-  // Replace all 0x0f (reset color) with \0x031,0
+  // Replace all 0x0f (reset to defaults) with \0x031,0 (should be extended to reset all text decorations as well)
   filteredLine.replace(QRegExp("\017"),"\0031,0");
+  // Replace all 0x03 without color number (reset color) with \0x031,0
+  filteredLine.replace(QRegExp("\003([^0-9]|$)"),"\0031,0\\1");
 
   if(filteredLine.find("\x07")!=-1)
   {
@@ -238,35 +267,50 @@ QString IRCView::filter(const QString& line,const QString& whoSent,bool doHiligh
   }
 
   // Hilight
+
   if(doHilight)
   {
+    highlightColor=QString::null;
+
     // FIXME: We got to get rid of server dependance here
-    if(server && KonversationApplication::preferences.getHilightNick() &&
-       filteredLine.lower().find(server->getNickname().lower())!=-1)
+    if(server && whoSent==server->getNickname() && KonversationApplication::preferences.getHilightOwnLines())
     {
-      QColor hilightNickColor=KonversationApplication::preferences.getHilightNickColor();
-      filteredLine=QString("<font color=\""+hilightNickColor.name()+"\">")+filteredLine+QString("</font>");
+      // hilight own lines
+      filteredLine=QString("<font color=\""+KonversationApplication::preferences.getHilightOwnLinesColor().name()+"\">")+filteredLine+QString("</font>");
     }
     else
     {
-      QPtrList<Highlight> hilightList=KonversationApplication::preferences.getHilightList();
-      unsigned int index;
+      QString who(QString::null);
+      // only copy sender name if it was not our own line
+      if(server && whoSent!=server->getNickname()) who=whoSent;
 
-      for(index=0;index<hilightList.count();index++)
+      // FIXME: We got to get rid of server dependance here
+      if(server && KonversationApplication::preferences.getHilightNick() &&
+         filteredLine.lower().find(QRegExp("\\b"+server->getNickname().lower()+"\\b"))!=-1)
       {
-        QString needle=hilightList.at(index)->getText().lower();
-        if(filteredLine.lower().find(needle)!=-1)
+        // hilight current nickname
+        highlightColor=KonversationApplication::preferences.getHilightNickColor().name();
+      }
+      else
+      {
+        QPtrList<Highlight> hilightList=KonversationApplication::preferences.getHilightList();
+        unsigned int index;
+
+        for(index=0;index<hilightList.count();index++)
         {
-          filteredLine=QString("<font color=\""+hilightList.at(index)->getColor().name()+"\">")+filteredLine+QString("</font>");
-          break;
-        }
-        if(who!=NULL && who.lower().find(needle)!=-1)
-        {
-          filteredLine=QString("<font color=\""+hilightList.at(index)->getColor().name()+"\">")+filteredLine+QString("</font>");
-          break;
-        }
-     } // endfor
+          QString needle=hilightList.at(index)->getText().lower();
+          if(filteredLine.lower().find(needle)!=-1 ||   // hilight patterns in text
+             who.lower().find(needle)!=-1 )             // hilight patterns in nickname
+          {
+            highlightColor=hilightList.at(index)->getColor().name();
+            break;
+          }
+        } // endfor
+      }
     }
+    // apply found highlight color to line
+    if(!highlightColor.isEmpty())
+      filteredLine=QString("<font color=\""+highlightColor+"\">")+filteredLine+QString("</font>");
   }
 
   // Replace multiple Spaces with "<space>&nbsp;"
@@ -279,7 +323,7 @@ QString IRCView::filter(const QString& line,const QString& whoSent,bool doHiligh
   return filteredLine;
 }
 
-void IRCView::append(const char* nick,const char* message)
+void IRCView::append(const QString& nick,const QString& message)
 {
   QString channelMessageColor = KonversationApplication::preferences.getChannelMessageColor();
 
@@ -289,7 +333,8 @@ void IRCView::append(const char* nick,const char* message)
 #ifdef ADD_LINE_BREAKS
   QString line=QString("<font color=\"#"+channelMessageColor+"\"><b>&lt;%1&gt;</b> %2</font><br>\n").arg(filter(nick,NULL,false)).arg(filter(message,nick));
 #else
-  QString line=QString("<font color=\"#"+channelMessageColor+"\"><b>&lt;%1&gt;</b> %2</font>\n").arg(filter(nick,NULL,false)).arg(filter(message,nick,true));
+//  QString line=QString("<font color=\"#"+channelMessageColor+"\"><b>&lt;%1&gt;</b> %2</font>\n").arg(filter(nick,NULL,false)).arg(filter(message,nick,true));
+  QString line=QString("<p><font color=\"#"+channelMessageColor+"\"><b>&lt;%1&gt;</b> %2</font></p>\n").arg(filter(nick,NULL,false)).arg(filter(message,nick,true));
 #endif
 #endif
 
@@ -298,7 +343,7 @@ void IRCView::append(const char* nick,const char* message)
   doAppend(line);
 }
 
-void IRCView::appendRaw(const char* message)
+void IRCView::appendRaw(const QString& message)
 {
   QString channelMessageColor = KonversationApplication::preferences.getChannelMessageColor();
 
@@ -308,14 +353,15 @@ void IRCView::appendRaw(const char* message)
 #ifdef ADD_LINE_BREAKS
   QString line=QString("<font color=\"#"+channelMessageColor+"\">"+message+"</font><br>\n");
 #else
-  QString line=QString("<font color=\"#"+channelMessageColor+"\">"+message+"</font>\n");
+//  QString line=QString("<font color=\"#"+channelMessageColor+"\">"+message+"</font>\n");
+  QString line=QString("<p><font color=\"#"+channelMessageColor+"\">"+message+"</font></p>\n");
 #endif
 #endif
 
   doAppend(line);
 }
 
-void IRCView::appendQuery(const char* nick,const char* message)
+void IRCView::appendQuery(const QString& nick,const QString& message)
 {
   QString queryMessageColor = KonversationApplication::preferences.getQueryMessageColor();
 
@@ -325,7 +371,8 @@ void IRCView::appendQuery(const char* nick,const char* message)
 #ifdef ADD_LINE_BREAKS
   QString line=QString("<font color=\"#"+queryMessageColor+"\"><b>*%1*</b> %2</font><br>\n").arg(filter(nick,NULL,false)).arg(filter(message,nick,true));
 #else
-  QString line=QString("<font color=\"#"+queryMessageColor+"\"><b>*%1*</b> %2</font>\n").arg(filter(nick,NULL,false)).arg(filter(message,nick,true));
+//  QString line=QString("<font color=\"#"+queryMessageColor+"\"><b>*%1*</b> %2</font>\n").arg(filter(nick,NULL,false)).arg(filter(message,nick,true));
+  QString line=QString("<p><font color=\"#"+queryMessageColor+"\"><b>*%1*</b> %2</font></p>\n").arg(filter(nick,NULL,false)).arg(filter(message,nick,true));
 #endif
 #endif
 
@@ -334,7 +381,7 @@ void IRCView::appendQuery(const char* nick,const char* message)
   doAppend(line);
 }
 
-void IRCView::appendAction(const char* nick,const char* message)
+void IRCView::appendAction(const QString& nick,const QString& message)
 {
   QString actionMessageColor = KonversationApplication::preferences.getActionMessageColor();
 
@@ -344,7 +391,8 @@ void IRCView::appendAction(const char* nick,const char* message)
 #ifdef ADD_LINE_BREAKS
   QString line=QString("<font color=\"#"+actionMessageColor+"\">* %1 %2</font><br>\n").arg(filter(nick,NULL,false)).arg(filter(message,nick,true));
 #else
-  QString line=QString("<font color=\"#"+actionMessageColor+"\">* %1 %2</font>\n").arg(filter(nick,NULL,false)).arg(filter(message,nick,true));
+//  QString line=QString("<font color=\"#"+actionMessageColor+"\">* %1 %2</font>\n").arg(filter(nick,NULL,false)).arg(filter(message,nick,true));
+  QString line=QString("<p><font color=\"#"+actionMessageColor+"\">* %1 %2</font></p>\n").arg(filter(nick,NULL,false)).arg(filter(message,nick,true));
 #endif
 #endif
 
@@ -353,7 +401,7 @@ void IRCView::appendAction(const char* nick,const char* message)
   doAppend(line);
 }
 
-void IRCView::appendServerMessage(const char* type,const char* message)
+void IRCView::appendServerMessage(const QString& type,const QString& message)
 {
   QString serverMessageColor=KonversationApplication::preferences.getServerMessageColor();
 
@@ -370,7 +418,8 @@ void IRCView::appendServerMessage(const char* type,const char* message)
 #ifdef ADD_LINE_BREAKS
   QString line=QString("<font color=\"#"+serverMessageColor+"\""+fixed+"><b>[%1]</b> %2</font><br>\n").arg(type).arg(filter(message));
 #else
-  QString line=QString("<font color=\"#"+serverMessageColor+"\""+fixed+"><b>[%1]</b> %2</font>\n").arg(type).arg(filter(message));
+//  QString line=QString("<font color=\"#"+serverMessageColor+"\""+fixed+"><b>[%1]</b> %2</font>\n").arg(type).arg(filter(message));
+  QString line=QString("<p><font color=\"#"+serverMessageColor+"\""+fixed+"><b>[%1]</b> %2</font></p>\n").arg(type).arg(filter(message));
 #endif
 #endif
   emit textToLog(QString("%1\t%2").arg(type).arg(message));
@@ -378,7 +427,7 @@ void IRCView::appendServerMessage(const char* type,const char* message)
   doAppend(line);
 }
 
-void IRCView::appendCommandMessage(const char* type,const char* message)
+void IRCView::appendCommandMessage(const QString& type,const QString& message)
 {
   QString commandMessageColor = KonversationApplication::preferences.getCommandMessageColor();
 
@@ -388,7 +437,8 @@ void IRCView::appendCommandMessage(const char* type,const char* message)
 #ifdef ADD_LINE_BREAKS
   QString line=QString("<font color=\"#"+commandMessageColor+"\">*** %2</font><br>\n").arg(filter(message));
 #else
-  QString line=QString("<font color=\"#"+commandMessageColor+"\">*** %2</font>\n").arg(filter(message));
+//  QString line=QString("<font color=\"#"+commandMessageColor+"\">*** %2</font>\n").arg(filter(message));
+  QString line=QString("<p><font color=\"#"+commandMessageColor+"\">*** %2</font></p>\n").arg(filter(message));
 #endif
 #endif
   emit textToLog(QString("%1\t%2").arg(type).arg(message));
@@ -396,7 +446,7 @@ void IRCView::appendCommandMessage(const char* type,const char* message)
   doAppend(line);
 }
 
-void IRCView::appendBacklogMessage(const char* firstColumn,const char* rawMessage)
+void IRCView::appendBacklogMessage(const QString& firstColumn,const QString& rawMessage)
 {
   QString time;
   QString message(rawMessage);
@@ -420,21 +470,18 @@ void IRCView::appendBacklogMessage(const char* firstColumn,const char* rawMessag
 #ifdef ADD_LINE_BREAKS
   QString line=QString("<font color=\"#"+backlogMessageColor+"\">%1 %2 %3</font><br>\n").arg(time).arg(first).arg(filter(message,NULL,false));
 #else
-  QString line=QString("<font color=\"#"+backlogMessageColor+"\">%1 %2 %3</font>\n").arg(time).arg(first).arg(filter(message,NULL,false));
+//  QString line=QString("<font color=\"#"+backlogMessageColor+"\">%1 %2 %3</font>\n").arg(time).arg(first).arg(filter(message,NULL,false));
+  QString line=QString("<p><font color=\"#"+backlogMessageColor+"\">%1 %2 %3</font></p>\n").arg(time).arg(first).arg(filter(message,NULL,false));
 #endif
 #endif
 
-  QTextCodec* codec=QTextCodec::codecForName(KonversationApplication::preferences.getCodec());
-  line=codec->fromUnicode(line);
   // no additional time stamps on backlog messages
   doAppend(line,true);
 }
 
 void IRCView::doAppend(QString newLine,bool suppressTimestamps)
 {
-  //  kdDebug() << "IRCView::doAppend("<< line << ")" << endl;
   // Add line to buffer
-
   QString line(newLine);
 
   if(!suppressTimestamps && KonversationApplication::preferences.getTimestamping())
@@ -442,14 +489,17 @@ void IRCView::doAppend(QString newLine,bool suppressTimestamps)
     QTime time=QTime::currentTime();
     QString timeColor=KonversationApplication::preferences.getTimeColor();
     QString timeFormat=KonversationApplication::preferences.getTimestampFormat();
-    line.prepend(QString("<font color=\"#"+timeColor+"\">[%1]</font> ").arg(time.toString(timeFormat)));
+    QString timeString(QString("<font color=\"#"+timeColor+"\">[%1]</font> ").arg(time.toString(timeFormat)));
+
+#ifdef ADD_LINE_BREAKS
+      line.prepend(timeString);
+#else
+      line.insert(3,timeString);
+#endif
   }
 
   buffer+=line;
-  emit newText();
-
-  QTextCodec* codec=QTextCodec::codecForName(KonversationApplication::preferences.getCodec());
-  line=codec->toUnicode(line);
+  emit newText(highlightColor);
 
   // scroll view only if the scroll bar is already at the bottom
 #if QT_VERSION == 303
@@ -465,19 +515,23 @@ void IRCView::doAppend(QString newLine,bool suppressTimestamps)
   KTextBrowser::append(line);
 #endif
 
-  if(doScroll) ensureVisible(0,contentsHeight());
+  if(doScroll)
+  {
+    moveCursor(MoveEnd,false);
+    ensureVisible(0,contentsHeight());
+  }
 }
 
 // Workaround to scroll to the end of the TextView when it's shown
 void IRCView::showEvent(QShowEvent* event)
 {
-  // kdDebug() << "IRCView::showEvent()" << endl;
   // Suppress Compiler Warning
   event->type();
 
 #ifdef TABLE_VERSION
   setText("<qt><table cellpadding=\"0\" cellspacing=\"0\">"+buffer+"</table></qt>");
 #endif
+  moveCursor(MoveEnd,false);
   ensureVisible(0,contentsHeight());
   // Set focus to input line (must be connected)
   emit gotFocus();
@@ -505,7 +559,6 @@ bool IRCView::eventFilter(QObject* object,QEvent* event)
     else if(me->button()==QMouseEvent::MidButton)
     {
       // TODO: maybe implement pasting here?
-      kdDebug() << "MMouse" << endl;
     }
   }
   else if(event->type()==QEvent::ContextMenu)
@@ -527,6 +580,17 @@ bool IRCView::contextMenu(QContextMenuEvent* ce)
     case Copy:
       copy();
       break;
+    case CopyUrl:
+    {
+      QClipboard *cb=KApplication::kApplication()->clipboard();
+#if QT_VERSION >= 0x030100
+      cb->setText(urlToCopy,QClipboard::Selection);
+#else
+      cb->setSelectionMode(true);
+      cb->setText(urlToCopy);
+#endif
+      break;
+    }
     case SelectAll:
       selectAll();
       break;
@@ -590,13 +654,19 @@ void IRCView::search()
       }
     }
 
-    kdDebug() << "Looking for " << pattern << " from paragraph " << findParagraph << " line " << findIndex << endl;
-
-    if(find(pattern,caseSensitive,wholeWords,forward,&findParagraph,&findIndex))
-      kdDebug() << "Found " << pattern << " on paragraph " << findParagraph << " line " << findIndex << endl;
-    else
+    if(!find(pattern,caseSensitive,wholeWords,forward,&findParagraph,&findIndex))
       KMessageBox::information(this,i18n("No matches found for \"%1\".").arg(pattern),i18n("Information"));
   }
 }
 
+void IRCView::pageUp()
+{
+  moveCursor(MovePgUp,false);
+}
+
+void IRCView::pageDown()
+{
+  moveCursor(MovePgDown,false);
+}
+
 #include "ircview.moc"
