@@ -1,6 +1,6 @@
 // Konversation DCOP interface class
 // by Alex Zepeda, March 7, 2003
-// $Id: konvdcop.cpp,v 1.5 2003/03/23 14:33:30 eisfuchs Exp $
+// $Id: konvdcop.cpp,v 1.8 2003/05/05 20:40:39 eisfuchs Exp $
 
 #include "konversationapplication.h"
 #include "konvdcop.h"
@@ -13,8 +13,7 @@
 #include <qstring.h>
 
 
-KonvDCOP::KonvDCOP() :
-           QObject(0,"Konversation"), DCOPObject("Konversation")
+KonvDCOP::KonvDCOP() : QObject(0,"Konversation"), DCOPObject("Konversation")
 {
   if(!kapp->dcopClient()->isRegistered())
   {
@@ -93,7 +92,7 @@ IRCEvent::IRCEvent (const QString &a_type, const QString &a_criteria, const QStr
     type = ON_NICK_CHANGE;
   } else if (l_type == "mode") {
     type = ON_MODE;
-  } else if (l_type = "numeric") {
+  } else if (l_type == "numeric") {
     type = ON_NUMERIC;
   } else {
     type = ON_ANY;
@@ -508,6 +507,16 @@ void KonvPrefsDCOP::setNotifyList(QStringList newList)
   static_cast<KonversationApplication *>(kapp)->saveOptions(true);
 }
 
+bool KonvPrefsDCOP::addNotify(QString newPattern)
+{
+  return KonversationApplication::preferences.addNotify(newPattern);
+}
+
+bool KonvPrefsDCOP::removeNotify(QString pattern)
+{
+  return KonversationApplication::preferences.removeNotify(pattern);
+}
+
 void KonvPrefsDCOP::addIgnore(QString newIgnore)
 {
   KonversationApplication::preferences.addIgnore(newIgnore);
