@@ -6,21 +6,23 @@
 */
 
 /*
-  konversationapplication.cpp  -  description
+  konversationapplication.cpp  -  The main application
   begin:     Mon Jan 28 2002
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: konversationapplication.cpp,v 1.66 2003/03/23 14:33:30 eisfuchs Exp $
+  $Id: konversationapplication.cpp,v 1.77 2003/05/25 17:41:05 eisfuchs Exp $
 */
 
-#include <kdebug.h>
+#include <qtextcodec.h>
 #include <qregexp.h>
+
+#include <kdebug.h>
 #include <dcopclient.h>
 
 #include "konversationapplication.h"
 #include "konvdcop.h"
-#include "serverwindow.h"
+#include "konversationmainwindow.h"
 
 // include static variables
 Preferences KonversationApplication::preferences;
@@ -37,6 +39,17 @@ KonversationApplication::KonversationApplication()
 
   readOptions();
 
+#if QT_VERSION >= 0x030100
+  // Setup system codec
+  // FIXME: change this to use per-identity codecs!
+  QTextCodec::setCodecForCStrings(QTextCodec::codecForName(preferences.getCodec().ascii()));
+#endif
+  
+  // open main window
+  mainWindow=new KonversationMainWindow();
+
+  connect(mainWindow,SIGNAL (openPrefsDialog()),this,SLOT (openPrefsDialog()) );
+
   // handle autoconnect on startup
   QValueList<int> list=preferences.getAutoConnectServerIDs();
   // if there is at least one autoconnect server, start connecting right away
@@ -58,8 +71,6 @@ KonversationApplication::KonversationApplication()
     connect(prefsDialog,SIGNAL (cancelClicked()),this,SLOT (quitKonversation()) );
     connect(prefsDialog,SIGNAL (prefsChanged()),this,SLOT (saveOptions()) );
 
-    serverList.setAutoDelete(false);     // don't delete items when they are removed
-
     prefsDialog->show();
 
     connect(&preferences,SIGNAL (requestServerConnection(int)),this,SLOT (connectToAnotherServer(int)) );
@@ -82,7 +93,8 @@ KonversationApplication::~KonversationApplication()
 {
   kdDebug() << "KonversationApplication::~KonversationApplication()" << endl;
   saveOptions(false);
-  delete dcopObject;
+
+  if(dcopObject) delete dcopObject;
 }
 
 void KonversationApplication::dcopSay(const QString& server,const QString& target,const QString& command)
@@ -93,18 +105,16 @@ void KonversationApplication::dcopSay(const QString& server,const QString& targe
     if(lookServer->getServerName()==server)
     {
       lookServer->dcopSay(target,command);
-      // break out of while loop
-      lookServer=0;
+      break; // leave while loop
     }
-    else lookServer=serverList.next();
+    lookServer=serverList.next();
   }
 }
 
 void KonversationApplication::dcopInfo(const QString& string)
 {
   Server* lookServer=serverList.first();
-  if(lookServer)
-    lookServer->dcopInfo(string);
+  if(lookServer) lookServer->dcopInfo(string);
 }
 
 void KonversationApplication::connectToServer(int id)
@@ -123,6 +133,8 @@ void KonversationApplication::connectToAnotherServer(int id)
 {
   kdDebug() << "KonversationApplication::connectToAnotherServer(" << id << ")" << endl;
 
+  mainWindow->show();
+
   ServerEntry* chosenServer=preferences.getServerEntryById(id);
 
   // Check if a server window with same name and port is already open
@@ -158,29 +170,46 @@ void KonversationApplication::connectToAnotherServer(int id)
   } // endwhile
   // We came this far, so generate a new server
 
-  newServer=new Server(id);
+  newServer=new Server(mainWindow,id);
+
+  connect(mainWindow,SIGNAL (startNotifyTimer(int)),newServer,SLOT (startNotifyTimer(int)) );
+  connect(mainWindow,SIGNAL (channelQuickButtonsChanged()),newServer,SLOT (updateChannelQuickButtons()) );
+  connect(mainWindow,SIGNAL (quitServer()),newServer,SLOT (quitServer()) );
+
+  connect(newServer,SIGNAL (nicksNowOnline(Server*,const QStringList&)),mainWindow,SLOT (setOnlineList(Server*,const QStringList&)) );
+
+  connect(newServer,SIGNAL (deleted(Server*)),this,SLOT (removeServer(Server*)) );
+
   serverList.append(newServer);
-
-  connect(newServer,SIGNAL(deleted(Server*)),this,SLOT(removeServer(Server*)));
-
-  connect(newServer->getServerWindow(),SIGNAL(prefsChanged()),this,SLOT(saveOptions()));
-  connect(newServer->getServerWindow(),SIGNAL(openPrefsDialog()),this,SLOT(openPrefsDialog()));
 }
 
-void KonversationApplication::removeServer(Server* server)
+Server* KonversationApplication::getServerByName(const QString& name)
 {
   Server* lookServer=serverList.first();
   while(lookServer)
   {
-    if(lookServer==server) serverList.remove();
-    else lookServer=serverList.next();
+    if(lookServer->getServerName()==name) return lookServer;
+    lookServer=serverList.next();
   }
+  return 0;
+}
+
+void KonversationApplication::removeServer(Server* server)
+{
+  kdDebug() << "KonversationApplication::removeServer()" << endl;
+
+  serverList.setAutoDelete(false);     // don't delete items when they are removed
+  if(!serverList.remove(server))
+    kdDebug() << "Could not remove " << server->getServerName() << endl;
 }
 
 void KonversationApplication::quitKonversation()
 {
   kdDebug() << "KonversationApplication::quitKonversation()" << endl;
-  delete prefsDialog;
+
+  if(prefsDialog) delete prefsDialog;
+  prefsDialog=0;
+
   this->exit();
 }
 
@@ -188,7 +217,9 @@ void KonversationApplication::readOptions()
 {
   kdDebug() << "KonversationApplication::readOptions()" << endl;
 
+  // get standard config file
   KConfig* config=kapp->config();
+
   // Read configuration and provide the default values
   config->setGroup("General Options");
 
@@ -196,19 +227,19 @@ void KonversationApplication::readOptions()
   preferences.setCommandChar(config->readEntry("CommandChar",preferences.getCommandChar()));
 
   // Tool bar position settings
-  preferences.serverWindowToolBarPos     =config->readNumEntry("ServerWindowToolBarPos",KToolBar::Top);
-  preferences.serverWindowToolBarStatus  =config->readNumEntry("ServerWindowToolBarStatus",KToolBar::Show);
-  preferences.serverWindowToolBarIconText=config->readNumEntry("ServerWindowToolBarIconText",KToolBar::IconTextBottom);
-  preferences.serverWindowToolBarIconSize=config->readNumEntry("ServerWindowToolBarIconSize",0);
+  preferences.mainWindowToolBarPos     =config->readNumEntry("ServerWindowToolBarPos",KToolBar::Top);
+  preferences.mainWindowToolBarStatus  =config->readNumEntry("ServerWindowToolBarStatus",KToolBar::Show);
+  preferences.mainWindowToolBarIconText=config->readNumEntry("ServerWindowToolBarIconText",KToolBar::IconTextBottom);
+  preferences.mainWindowToolBarIconSize=config->readNumEntry("ServerWindowToolBarIconSize",0);
 
   // Status bar settings
-  preferences.serverWindowStatusBarStatus=config->readBoolEntry("ServerWindowStatusBarStatus",true);
+  preferences.mainWindowStatusBarStatus=config->readBoolEntry("ServerWindowStatusBarStatus",true);
 
   // Menu bar settings
-  preferences.serverWindowMenuBarStatus=config->readBoolEntry("ServerWindowMenuBarStatus",true);
+  preferences.mainWindowMenuBarStatus=config->readBoolEntry("ServerWindowMenuBarStatus",true);
 
   // Window geometries
-  preferences.setServerWindowSize(config->readSizeEntry("Geometry"));
+  preferences.setMainWindowSize(config->readSizeEntry("Geometry"));
   preferences.setHilightSize(config->readSizeEntry("HilightGeometry"));
   preferences.setButtonsSize(config->readSizeEntry("ButtonsGeometry"));
   preferences.setIgnoreSize(config->readSizeEntry("IgnoreGeometry"));
@@ -223,10 +254,10 @@ void KonversationApplication::readOptions()
 
   // Beep
   preferences.setBeep(config->readBoolEntry("Beep",preferences.getBeep()));
-  
+
   // Raw log window
   preferences.setRawLog(config->readBoolEntry("RawLog",preferences.getRawLog()));
-  
+
   // Appearance
   config->setGroup("Appearance");
   // Fonts
@@ -243,12 +274,15 @@ void KonversationApplication::readOptions()
   preferences.setSpacing(config->readNumEntry("Spacing",preferences.getSpacing()));
   preferences.setMargin(config->readNumEntry("Margin",preferences.getMargin()));
 
+  preferences.setUseParagraphSpacing(config->readBoolEntry("UseParagraphSpacing",preferences.getUseParagraphSpacing()));
+  preferences.setParagraphSpacing(config->readNumEntry("ParagraphSpacing",preferences.getParagraphSpacing()));
+
   QValueList<int> sizes;
   QString sizesString=config->readEntry("ChannelSplitter","10,1");
   sizes.append(sizesString.section(',',0,0).toInt());
   sizes.append(sizesString.section(',',1,1).toInt());
   preferences.setChannelSplitter(sizes);
-  
+
   // Colors
   config->setGroup("Message Text Colors");
 
@@ -268,6 +302,14 @@ void KonversationApplication::readOptions()
   preferences.setVoiceLedColor(config->readNumEntry("VoiceColor",preferences.getVoiceLedColor()));
   preferences.setNoRightsLedColor(config->readNumEntry("NoRightsColor",preferences.getNoRightsLedColor()));
 
+  // Sorting
+  config->setGroup("Sort Nicknames");
+  preferences.setOpValue(config->readNumEntry("OperatorValue",preferences.getOpValue()));
+  preferences.setVoiceValue(config->readNumEntry("VoiceValue",preferences.getVoiceValue()));
+  preferences.setNoRightsValue(config->readNumEntry("NoRightsValue",preferences.getNoRightsValue()));
+  preferences.setSortByStatus(config->readBoolEntry("SortByStatus",preferences.getSortByStatus()));
+  preferences.setSortCaseInsensitive(config->readBoolEntry("SortCaseInsensitive",preferences.getSortCaseInsensitive()));
+
   // Identity list
   QStringList identityList=config->groupList().grep(QRegExp("Identity [0-9]+"));
   if(identityList.count())
@@ -375,7 +417,6 @@ void KonversationApplication::readOptions()
   else
     preferences.setHilightOwnLinesColor("#"+hilight);
 
-    
   // Ignore List
   config->setGroup("Ignore List");
   // Remove all default entries if there is at least one Ignore in the preferences file
@@ -432,7 +473,7 @@ void KonversationApplication::saveOptions(bool updateGUI)
 
   config->writeEntry("CommandChar",preferences.getCommandChar());
 
-  config->writeEntry("Geometry",preferences.getServerWindowSize());
+  config->writeEntry("Geometry",preferences.getMainWindowSize());
   config->writeEntry("HilightGeometry",preferences.getHilightSize());
   config->writeEntry("ButtonsGeometry",preferences.getButtonsSize());
   config->writeEntry("IgnoreGeometry",preferences.getIgnoreSize());
@@ -441,14 +482,14 @@ void KonversationApplication::saveOptions(bool updateGUI)
   config->writeEntry("NicknameGeometry",preferences.getNicknameSize());
   config->writeEntry("ColorConfigurationGeometry", preferences.getColorConfigurationSize());
 
-  config->writeEntry("ServerWindowToolBarPos",preferences.serverWindowToolBarPos);
-  config->writeEntry("ServerWindowToolBarStatus",preferences.serverWindowToolBarStatus);
-  config->writeEntry("ServerWindowToolBarIconText",preferences.serverWindowToolBarIconText);
-  config->writeEntry("ServerWindowToolBarIconSize",preferences.serverWindowToolBarIconSize);
+  config->writeEntry("ServerWindowToolBarPos",preferences.mainWindowToolBarPos);
+  config->writeEntry("ServerWindowToolBarStatus",preferences.mainWindowToolBarStatus);
+  config->writeEntry("ServerWindowToolBarIconText",preferences.mainWindowToolBarIconText);
+  config->writeEntry("ServerWindowToolBarIconSize",preferences.mainWindowToolBarIconSize);
 
-  config->writeEntry("ServerWindowStatusBarStatus",preferences.serverWindowStatusBarStatus);
+  config->writeEntry("ServerWindowStatusBarStatus",preferences.mainWindowStatusBarStatus);
 
-  config->writeEntry("ServerWindowMenuBarStatus",preferences.serverWindowMenuBarStatus);
+  config->writeEntry("ServerWindowMenuBarStatus",preferences.mainWindowMenuBarStatus);
 
   config->writeEntry("ChannelDoubleClickAction",preferences.getChannelDoubleClickAction());
   config->writeEntry("NotifyDoubleClickAction",preferences.getNotifyDoubleClickAction());
@@ -465,26 +506,36 @@ void KonversationApplication::saveOptions(bool updateGUI)
   config->writeEntry("ShowQuickButtons",preferences.getShowQuickButtons());
   config->writeEntry("ShowModeButtons",preferences.getShowModeButtons());
   config->writeEntry("CloseButtonsOnTabs",preferences.getCloseButtonsOnTabs());
-  config->writeEntry("Codec",preferences.getCodec());
+  config->writeEntry("Codec",preferences.getCodec().stripWhiteSpace());
 
   config->writeEntry("UseSpacing",preferences.getUseSpacing());
   config->writeEntry("Spacing",preferences.getSpacing());
   config->writeEntry("Margin",preferences.getMargin());
-  
+
+  config->writeEntry("UseParagraphSpacing",preferences.getUseParagraphSpacing());
+  config->writeEntry("ParagraphSpacing",preferences.getParagraphSpacing());
+
   QString sizesString(QString::number(preferences.getChannelSplitter()[0])+","+QString::number(preferences.getChannelSplitter()[1]));
   config->writeEntry("ChannelSplitter",sizesString);
 
   config->setGroup("Message Text Colors");
 
-  config->writeEntry("ActionMessage", preferences.getActionMessageColor());
-  config->writeEntry("BacklogMessage", preferences.getBacklogMessageColor());
-  config->writeEntry("ChannelMessage", preferences.getChannelMessageColor());
-  config->writeEntry("CommandMessage", preferences.getCommandMessageColor());
-  config->writeEntry("LinkMessage", preferences.getLinkMessageColor());
-  config->writeEntry("QueryMessage", preferences.getQueryMessageColor());
-  config->writeEntry("ServerMessage", preferences.getServerMessageColor());
-  config->writeEntry("Time", preferences.getTimeColor());
-  config->writeEntry("TextViewBackground", preferences.getTextViewBackground());
+  config->writeEntry("ActionMessage",preferences.getActionMessageColor());
+  config->writeEntry("BacklogMessage",preferences.getBacklogMessageColor());
+  config->writeEntry("ChannelMessage",preferences.getChannelMessageColor());
+  config->writeEntry("CommandMessage",preferences.getCommandMessageColor());
+  config->writeEntry("LinkMessage",preferences.getLinkMessageColor());
+  config->writeEntry("QueryMessage",preferences.getQueryMessageColor());
+  config->writeEntry("ServerMessage",preferences.getServerMessageColor());
+  config->writeEntry("Time",preferences.getTimeColor());
+  config->writeEntry("TextViewBackground",preferences.getTextViewBackground());
+
+  config->setGroup("Sort Nicknames");
+  config->writeEntry("OperatorValue",preferences.getOpValue());
+  config->writeEntry("VoiceValue",preferences.getVoiceValue());
+  config->writeEntry("NoRightsValue",preferences.getNoRightsValue());
+  config->writeEntry("SortByStatus",preferences.getSortByStatus());
+  config->writeEntry("SortCaseInsensitive",preferences.getSortCaseInsensitive());
 
   config->setGroup("Led Colors");
   config->writeEntry("OperatorColor", preferences.getOpLedColor());
@@ -533,7 +584,7 @@ void KonversationApplication::saveOptions(bool updateGUI)
   int index=0;
   QString serverEntry=preferences.getServerByIndex(0);
 
-  while(serverEntry)
+  while(!serverEntry.isEmpty())
   {
     config->writeEntry(QString("Server%1").arg(index),serverEntry);
     serverEntry=preferences.getServerByIndex(++index);
@@ -634,6 +685,7 @@ void KonversationApplication::saveOptions(bool updateGUI)
 
 void KonversationApplication::storeURL(const QString &url)
 {
+  // FIXME: use KURL, check that we don't add the same URL twice
   urlList.append(url);
 }
 
