@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: ledtab.cpp,v 1.7 2003/03/05 10:17:15 eisfuchs Exp $
+  $Id: ledtab.cpp,v 1.8 2003/05/11 23:12:12 eisfuchs Exp $
 */
 
 #include <kdebug.h>
@@ -31,6 +31,7 @@ LedTab::LedTab(QWidget* newWidget,const QString& label,int newColor,bool state)
   color=newColor;
   blinkOn=true;
   widget=newWidget;
+  labelColor=QString::null;
 
   setOn(state);
 
@@ -74,6 +75,17 @@ void LedTab::setOn(bool state)
   setIconSet((on) ? iconOn : iconOff);
 }
 
+void LedTab::setLabelColor(const QString& newLabelColor)
+{
+  labelColor=newLabelColor;
+  emit repaintTab(this);
+}
+
+const QString& LedTab::getLabelColor()
+{
+  return (blinkOn) ? labelColor : QString::null;
+}
+
 void LedTab::setIconSet(const QIconSet& icon)
 {
   delete iconSet();
