@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: ledtab.h,v 1.5 2003/03/05 10:17:15 eisfuchs Exp $
+  $Id: ledtab.h,v 1.7 2003/05/25 18:55:49 eisfuchs Exp $
 */
 
 
@@ -37,6 +37,8 @@ class LedTab : public QObject,public QTab
     ~LedTab();
 
     void setOn(bool state);
+    void setLabelColor(const QString& newLabelColor);
+    const QString& getLabelColor();
 
     QWidget* getWidget();
 
@@ -44,6 +46,12 @@ class LedTab : public QObject,public QTab
     QIconSet iconOff;
     QTimer blinkTimer;
 
+  signals:
+    void repaintTab(LedTab* myself);
+
+  protected slots:
+    void blinkTimeout();
+
   protected:
     void setIconSet(const QIconSet& icon);
 
@@ -53,12 +61,7 @@ class LedTab : public QObject,public QTab
 
     QWidget* widget;
     Images images;
-
-  signals:
-    void repaintTab(LedTab* myself);
-
-  protected slots:
-    void blinkTimeout();
+    QString labelColor;
 };
 
 #endif
