@@ -12,7 +12,7 @@
              in parts (C) by Trolltech
   email:     eisfuchs@tigress.com
 
-  $Id: ledtabbar.cpp,v 1.13 2003/03/19 16:14:44 eisfuchs Exp $
+  $Id: ledtabbar.cpp,v 1.17 2003/05/25 18:55:49 eisfuchs Exp $
 */
 
 #include <qpainter.h>
@@ -178,26 +178,32 @@ void LedTabBar::paint( QPainter * p, QTab * t, bool selected ) const
 }
 
 // original code by Trolltech, adapted for close pixmap
-void LedTabBar::paintLabel( QPainter* p, const QRect& br, QTab* t, bool has_focus ) const
+void LedTabBar::paintLabel( QPainter* p, const QRect& br, QTab* tab, bool has_focus ) const
 {
-  // do we want close widgets on the tabs?
-  if(KonversationApplication::preferences.getCloseButtonsOnTabs())
-  {
-    QRect r = br;
-    bool selected = currentTab() == t->identifier();
-    if ( t->iconSet()) {
-        // the tab has an iconset, draw it in the right mode
-        QIconSet::Mode mode = (t->isEnabled() && isEnabled())
-            ? QIconSet::Normal : QIconSet::Disabled;
-        if ( mode == QIconSet::Normal && has_focus )
-            mode = QIconSet::Active;
-        QPixmap pixmap = t->iconSet()->pixmap( QIconSet::Small, mode );
-        QPixmap close_pixmap(remove_xpm);
-        int pixw = pixmap.width();
-        int pixh = pixmap.height();
-        int close_pixh = close_pixmap.height();
-        r.setLeft( r.left() + pixw + LABEL_OFFSET);
-        r.setRight( r.right() + 2 + LABEL_OFFSET);
+  LedTab* t=static_cast<LedTab*>(tab);
+
+  QRect r = br;
+  bool selected = currentTab() == t->identifier();
+  if ( t->iconSet()) {
+      // the tab has an iconset, draw it in the right mode
+      QIconSet::Mode mode = (t->isEnabled() && isEnabled())
+          ? QIconSet::Normal : QIconSet::Disabled;
+      if ( mode == QIconSet::Normal && has_focus )
+          mode = QIconSet::Active;
+      QPixmap pixmap = t->iconSet()->pixmap( QIconSet::Small, mode );
+      QPixmap close_pixmap(remove_xpm);
+      int pixw = pixmap.width();
+      int pixh = pixmap.height();
+      int close_pixh = close_pixmap.height();
+
+      r.setLeft( r.left() + pixw);
+      r.setRight( r.right() + 2);
+
+      // do we want close widgets on the tabs?
+      if(KonversationApplication::preferences.getCloseButtonsOnTabs())
+      {
+        r.setLeft( r.left() + LABEL_OFFSET);
+        r.setRight( r.right() + LABEL_OFFSET);
         // ### the pixmap shift should probably not be hardcoded..
         p->drawPixmap( br.left() + 6 + LABEL_OFFSET /* + ((selected == TRUE) ? 0 : 1) */,
                        br.center().y()-pixh/2 + ((selected == TRUE) ? 0 : 1),
@@ -206,6 +212,14 @@ void LedTabBar::paintLabel( QPainter* p, const QRect& br, QTab* t, bool has_focu
         p->drawPixmap( br.left(),
                        br.center().y()-close_pixh/2,
                        close_pixmap );
+      }
+      else
+      {
+        // ### the pixmap shift should probably not be hardcoded..
+        p->drawPixmap( br.left() + 2 /* + ((selected == TRUE) ? 0 : 1) */,
+                       br.center().y()-pixh/2 + ((selected == TRUE) ? 0 : 1),
+                       pixmap );
+      }
     }
 
     QStyle::SFlags flags = QStyle::Style_Default;
@@ -215,12 +229,18 @@ void LedTabBar::paintLabel( QPainter* p, const QRect& br, QTab* t, bool has_focu
     if (has_focus)
         flags |= QStyle::Style_HasFocus;
 
+    // set new label color if there is one
+    QColorGroup  myColorGroup(colorGroup());
+    if(!t->getLabelColor().isEmpty())
+    {
+      myColorGroup.setColor(QColorGroup::Foreground,t->getLabelColor());
+      // most styles use Foreground, dotNET up to 1.4 uses Mid  ...
+      myColorGroup.setColor(QColorGroup::Mid,t->getLabelColor());
+    }
+
     style().drawControl( QStyle::CE_TabBarLabel, p, this, r,
-                         t->isEnabled() ? colorGroup(): palette().disabled(),
+                         t->isEnabled() ? myColorGroup : palette().disabled(),
                          flags, QStyleOption(t) );
-  }
-  // otherwise call original code
-  else QTabBar::paintLabel( p, br, t, has_focus );
 }
 
 // reimplemented for close pixmap
