@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: ledtabwidget.h,v 1.9 2003/03/05 00:03:15 eisfuchs Exp $
+  $Id: ledtabwidget.h,v 1.11 2003/05/11 23:12:12 eisfuchs Exp $
 */
 
 #ifndef LEDTABWIDGET_H
@@ -20,13 +20,14 @@
 #include <qtabwidget.h>
 
 #include "ledtabbar.h"
-#include "chatwindow.h"
 #include "images.h"
 
 /*
   @author Dario Abatianni
 */
 
+class ChatWindow;
+
 class LedTabWidget : public QTabWidget
 {
   Q_OBJECT
@@ -35,9 +36,10 @@ class LedTabWidget : public QTabWidget
     LedTabWidget(QWidget* parent,const char* name);
     ~LedTabWidget();
 
-    void addTab(QWidget* child,const QString& label,int color,bool on);
-    void changeTabState(QWidget* child,bool state);
+    void addTab(ChatWindow* child,const QString& label,int color,bool on);
+    void changeTabState(QWidget* child,bool state,const QString& labelColor);
     void connectTabUpdate(QObject* object);
+    void updateTabs();
 
   signals:
     void closeTab(QWidget* view);
@@ -45,7 +47,7 @@ class LedTabWidget : public QTabWidget
   protected slots:
     void tabSelected(int id);
     void tabClosed(int id);
-    void updateTabs();
+    void changeName(ChatWindow* view,const QString& newName);
 
   protected:
     LedTabBar* tabBar();
