@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: nick.h,v 1.8 2003/03/06 15:06:09 eisfuchs Exp $
+  $Id: nick.h,v 1.9 2003/04/02 15:13:38 eisfuchs Exp $
 */
 
 #ifndef NICK_H
@@ -32,15 +32,15 @@ class Nick
     Nick(KListView* listView, const QString &nickname, const QString &hostmask, bool op, bool voice);
     ~Nick();
 
-    bool isOp() { return op; };
-    bool hasVoice() { return voice; };
+    bool isOp();
+    bool hasVoice();
     void setOp(bool setop);
     void setVoice(bool setvoice);
-    bool isSelected() { return listViewItem->isSelected(); } ;
+    bool isSelected();
 
-    QString getNickname() { return nickname; };
-    QString getHostmask() { return hostmask; };
-    void setHostmask(const QString& newMask) { hostmask=newMask; };
+    QString getNickname();
+    QString getHostmask();
+    void setHostmask(const QString& newMask);
     void setNickname(const QString& newName);
 
   protected:
