@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: nicklistview.h,v 1.4 2003/03/02 15:51:45 eisfuchs Exp $
+  $Id: nicklistview.h,v 1.5 2003/03/28 00:20:29 eisfuchs Exp $
 */
 
 
@@ -37,8 +37,10 @@ class NickListView : public KListView
 
     enum PopupIDs
     {
-      Modes,GiveOp,TakeOp,GiveVoice,TakeVoice,
-      Kick,KickBan,BanNick,BanHostmask,
+      ModesSub,GiveOp,TakeOp,GiveVoice,TakeVoice,
+      KickBanSub,Kick,KickBan,BanNick,
+      BanHost,BanDomain,BanUserHost,BanUserDomain,
+      KickBanHost,KickBanDomain,KickBanUserHost,KickBanUserDomain,
       Whois,Version,Ping,Query,DccSend,
       CustomID
     };
@@ -52,6 +54,7 @@ class NickListView : public KListView
 
     QPopupMenu* popup;
     QPopupMenu* modes;
+    QPopupMenu* kickban;
 };
 
 #endif
