@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: notifydialog.cpp,v 1.8 2003/03/23 14:33:30 eisfuchs Exp $
+  $Id: notifydialog.cpp,v 1.9 2003/05/12 11:59:43 eisfuchs Exp $
 */
 
 #include <qlayout.h>
@@ -26,7 +26,7 @@
 #include "notifydialog.h"
 
 NotifyDialog::NotifyDialog(QStringList newNotifyList,QSize newSize,bool use,int delay):
-               KDialogBase(0,"notifydialog",false,i18n("Edit notify list"),
+               KDialogBase(static_cast<QWidget*>(0),"notifydialog",false,i18n("Edit notify list"),
                            KDialogBase::Ok | KDialogBase::Apply | KDialogBase::Cancel,
                            KDialogBase::Ok,true)
 {
