@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: outputfilter.cpp,v 1.46 2003/03/19 17:41:42 eisfuchs Exp $
+  $Id: outputfilter.cpp,v 1.58 2003/05/22 12:40:24 eisfuchs Exp $
 */
 
 #include <qstringlist.h>
@@ -21,6 +21,7 @@
 
 #include <klocale.h>
 #include <kdebug.h>
+#include <kio/passdlg.h>
 
 #include "konversationapplication.h"
 #include "outputfilter.h"
@@ -98,10 +99,15 @@ QString& OutputFilter::parse(const QString& myNick,const QString& originalLine,c
     else if(line.startsWith("kick "))    parseKick(parameter);
     else if(line.startsWith("topic "))   parseTopic(parameter);
     else if(line.startsWith("away "))    parseAway(parameter);
-    else if(line.startsWith("dcc "))     parseDcc(parameter);
     else if(line.startsWith("invite "))  parseInvite(parameter);
     else if(line.startsWith("exec "))    parseExec(parameter);
+    else if(line.startsWith("notify "))  parseNotify(parameter);
+    else if(line.startsWith("oper "))    parseOper(myNick,parameter);
+    else if(line.startsWith("ban "))     parseBan(parameter);
+
     else if(line.startsWith("raw "))     parseRaw(parameter);
+    else if(line.startsWith("dcc "))     parseDcc(parameter);
+    else if(line.startsWith("konsole ")) parseKonsole();
 
     else if(line=="join")                parseJoin(QString::null);
     else if(line=="part")                parsePart(QString::null);
@@ -112,10 +118,15 @@ QString& OutputFilter::parse(const QString& myNick,const QString& originalLine,c
     else if(line=="topic")               parseTopic(QString::null);
     else if(line=="away")                parseAway(QString::null);
     else if(line=="unaway")              parseAway(QString::null);
-    else if(line=="dcc")                 parseDcc(QString::null);
     else if(line=="invite")              parseInvite(QString::null);
     else if(line=="exec")                parseExec(QString::null);
+    else if(line=="notify")              parseNotify(QString::null);
+    else if(line=="oper")                parseOper(myNick,QString::null);
+    else if(line=="ban")                 parseBan(QString::null);
+
+    else if(line=="dcc")                 parseDcc(QString::null);
     else if(line=="raw")                 parseRaw(QString::null);
+    else if(line=="konsole")             parseKonsole();
 
     // Forward unknown commands to server
     else toServer=inputLine.mid(1);
@@ -187,7 +198,7 @@ void OutputFilter::parseKick(const QString &parameter)
       // get kick reason (if any)
       QString reason=parameter.mid(victim.length()+1);
       // if no reason given, take default reason
-      if(reason.isEmpty()) reason=identity->getKickReason();
+      if(reason.isEmpty()) reason=identity.getKickReason();
       toServer="KICK "+destination+" "+victim+" :"+reason;
     }
   }
@@ -205,7 +216,7 @@ void OutputFilter::parsePart(const QString &parameter)
   if(parameter.isEmpty())
   {
     // But only if we actually are in a channel
-    if(isAChannel(destination)) toServer="PART "+destination+" :"+identity->getPartReason();
+    if(isAChannel(destination)) toServer="PART "+destination+" :"+identity.getPartReason();
     else
     {
       type=i18n("Error");
@@ -223,7 +234,7 @@ void OutputFilter::parsePart(const QString &parameter)
       // get part reason (if any)
       QString reason=parameter.mid(channel.length()+1);
       // if no reason given, take default reason
-      if(reason.isEmpty()) reason=identity->getPartReason();
+      if(reason.isEmpty()) reason=identity.getPartReason();
       toServer="PART "+channel+" :"+reason;
     }
     // part this channel with a given reason
@@ -286,17 +297,17 @@ void OutputFilter::parseAway(const QString &reason)
 {
   if(reason.isEmpty())
   {
-    if(identity->getShowAwayMessage())
-      sendToAllChannels(identity->getReturnMessage());
+    if(identity.getShowAwayMessage())
+      sendToAllChannels(identity.getReturnMessage());
 
     emit unAway();
     toServer="AWAY";
   }
   else
   {
-    if(identity->getShowAwayMessage())
+    if(identity.getShowAwayMessage())
     {
-      QString message=identity->getAwayMessage();
+      QString message=identity.getAwayMessage();
       sendToAllChannels(message.replace(QRegExp("%s",false),reason));
     }
 
@@ -312,9 +323,9 @@ void OutputFilter::parseQuit(const QString &reason)
   toServer = "QUIT :";
   // if no reason given, take default reason
   if(reason.isEmpty())
-    toServer += identity->getPartReason();
+    toServer+=identity.getPartReason();
   else
-    toServer += reason;
+    toServer+=reason;
 }
 
 void OutputFilter::parseNotice(const QString &parameter)
@@ -399,7 +410,6 @@ void OutputFilter::parseCtcp(const QString &parameter)
 void OutputFilter::parseQuery(const QString &parameter)
 {
   QStringList queryList=QStringList::split(' ',parameter);
-
   for(unsigned int index=0;index<queryList.count();index++) emit openQuery(queryList[index],QString::null);
 }
 
@@ -455,18 +465,13 @@ void OutputFilter::parseDcc(const QString &parameter)
     else if(dccType=="send")
     {
       if(parameterList.count()==1)                 // DCC SEND
-      {
         emit requestDccSend();
-        kdDebug() << "Yo" << endl;
-      }
       else if(parameterList.count()==2)            // DCC SEND <nickname>
-      {
         emit requestDccSend(parameterList[1]);
-      }
       else if(parameterList.count()>2)             // DCC SEND <nickname> <file> [file] ...
       {
 // TODO: make sure this will work:
-//        output=i18n("Usage: %1DCC SEND nickname [filename] [filename] ...").arg(commandChar);
+//        output=i18n("Usage: %1DCC SEND nickname [fi6lename] [filename] ...").arg(commandChar);
         QFile file(parameterList[2]);
         if(file.exists())
           emit openDccSend(parameterList[1],parameterList[2]);
@@ -583,7 +588,7 @@ void OutputFilter::parseExec(const QString& parameter)
 void OutputFilter::parseRaw(const QString& parameter)
 {
   if(parameter.isEmpty() || parameter=="open")
-    emit openRawLog();
+    emit openRawLog(true);
   else if(parameter=="close")
     emit closeRawLog();
   else
@@ -594,6 +599,131 @@ void OutputFilter::parseRaw(const QString& parameter)
   }
 }
 
+void OutputFilter::parseNotify(const QString& parameter)
+{
+  if(!parameter.isEmpty())
+  {
+    QStringList list=QStringList::split(' ',parameter);
+
+    for(unsigned int index=0;index<list.count();index++)
+    {
+      // Try to remove current pattern
+      if(!KonversationApplication::preferences.removeNotify(list[index]))
+      {
+        // If remove failed, try to add it instead
+        if(!KonversationApplication::preferences.addNotify(list[index]))
+          kdDebug() << "OutputFilter::parseNotify(): Adding failed!" << endl;
+      }
+    } // endfor
+  }
+
+  // show (new) notify list to user
+  QString list=KonversationApplication::preferences.getNotifyString();
+  type=i18n("Notify");
+
+  if(list.isEmpty())
+    output=i18n("Current notify list is empty.");
+  else
+    output=i18n("Current notify list: %1").arg(list);
+
+  program=true;
+}
+
+void OutputFilter::parseOper(const QString& myNick,const QString& parameter)
+{
+  QStringList parameterList=QStringList::split(' ',parameter);
+  
+  if(parameter.isEmpty() || parameterList.count()==1)
+  {
+    QString nick((parameterList.count()==1) ? parameterList[0] : myNick);
+    QString password;
+    bool keep=false;
+
+    int result=KIO::PasswordDialog::getNameAndPassword
+                                    (
+                                      nick,
+                                      password,
+                                      &keep,
+                                      i18n("Enter user name and password for IRC operator privileges"),
+                                      false,
+                                      i18n("IRC operator password")
+                                    );
+
+    if(result==KIO::PasswordDialog::Accepted) toServer="OPER "+nick+" "+password;
+  }
+  else
+  {
+    toServer="OPER "+parameter;
+  }
+}
+
+void OutputFilter::parseBan(const QString& parameter)
+{
+  // assume incorrect syntax first
+  bool showUsage=true;
+  
+  if(parameter.isEmpty()) showUsage=true;
+  else
+  {
+    QStringList parameterList=QStringList::split(' ',parameter);
+    QString channel=QString::null;
+    QString option=QString::null;
+    // check for option
+    bool host=(parameterList[0].lower()=="-host");
+    bool domain=(parameterList[0].lower()=="-domain");
+    bool uhost=(parameterList[0].lower()=="-userhost");
+    bool udomain=(parameterList[0].lower()=="-userdomain");
+    
+    // remove possible option
+    if(host || domain || uhost || udomain)
+    {
+      option=parameterList[0].mid(1);
+      parameterList.pop_front();
+    }
+    
+    // look for channel / ban mask
+    if(parameterList.count())
+    {
+      // user specified channel
+      if(isAChannel(parameterList[0]))
+      {
+        channel=parameterList[0];
+        parameterList.pop_front();
+      }
+      // no channel, so assume current destination as channel
+      else if(isAChannel(destination))
+        channel=destination;
+      else
+      {
+        // destination is no channel => error
+        error(i18n("BAN without channel name works only from inside a channel."));
+        // no usage information after error
+        showUsage=false;
+      }
+      // signal server to ban this user if all went fine
+      if(!channel.isEmpty())
+      {
+        emit banUsers(parameterList,channel,option);
+        // syntax was correct, so reset flag
+        showUsage=false;
+      }
+    }
+  }
+
+  if(showUsage) usage(i18n("Usage: BAN [-HOST | -DOMAIN] [channel] <user|mask>"));
+}
+
+// finally set the ban
+void OutputFilter::execBan(const QString& mask,const QString& channel)
+{
+  toServer="MODE "+channel+" +b "+mask;
+}
+
+void OutputFilter::parseKonsole()
+{
+  emit openKonsolePanel();
+}
+
 // Accessors
 
 // Maybe we should switch to values instead of flags
@@ -603,7 +733,12 @@ bool OutputFilter::isProgram() { return program; };
 bool OutputFilter::isQuery() { return query; };
 
 void OutputFilter::setCommandChar() { commandChar=KonversationApplication::preferences.getCommandChar(); }
-void OutputFilter::setIdentity(const Identity *newIdentity) { identity=newIdentity; }
+void OutputFilter::setIdentity(const Identity *newIdentity)
+{
+  identity=*newIdentity;
+  // TODO: move this into copy constructor! THis does not work yet!
+  identity.setNicknameList(newIdentity->getNicknameList());
+}
 
 QString& OutputFilter::getOutput() { return output; };
 QString& OutputFilter::getServerOutput() { return toServer; };
@@ -617,4 +752,18 @@ bool OutputFilter::isAChannel(const QString &check)
   return (initial=='#' || initial=='&' || initial=='+' || initial=='!');
 }
 
+void OutputFilter::usage(const QString& string)
+{
+  type=i18n("Usage");
+  output=string;
+  program=true;
+}
+
+void OutputFilter::error(const QString& string)
+{
+  type=i18n("Error");
+  output=string;
+  program=true;
+}
+
 #include "outputfilter.moc"
