@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: preferences.cpp,v 1.54 2003/03/23 14:33:30 eisfuchs Exp $
+  $Id: preferences.cpp,v 1.60 2003/05/12 11:59:43 eisfuchs Exp $
 */
 
 #include <ktoolbar.h>
@@ -27,9 +27,9 @@
 Preferences::Preferences()
 {
   // Presets
-  serverWindowToolBarPos=KToolBar::Top;
-  serverWindowStatusBarStatus=true;
-  serverWindowMenuBarStatus=true;
+  mainWindowToolBarPos=KToolBar::Top;
+  mainWindowStatusBarStatus=true;
+  mainWindowMenuBarStatus=true;
   serverList.setAutoDelete(true);
 
   // create default identity
@@ -83,9 +83,12 @@ Preferences::Preferences()
   setSpacing(2);
   setMargin(3);
 
+  setUseParagraphSpacing(false);
+  setParagraphSpacing(2);
+
   channelSplitter.append(10);
   channelSplitter.append(1);
-  
+
   setAutoReconnect(true);
   setAutoRejoin(true);
 
@@ -131,6 +134,12 @@ Preferences::Preferences()
   setCommandChar("/");
   setChannelDoubleClickAction("/WHOIS %u%n");
   setNotifyDoubleClickAction("/WHOIS %u%n");
+
+  setOpValue(1);
+  setVoiceValue(2);
+  setNoRightsValue(4);
+  setSortCaseInsensitive(true);
+  setSortByStatus(false);
 }
 
 Preferences::~Preferences()
@@ -300,11 +309,23 @@ void Preferences::setUseNotify(bool use) { useNotify=use; }
 void Preferences::setNotifyList(const QStringList &newList) { notifyList=newList; }
 QStringList Preferences::getNotifyList() { return notifyList; }
 QString Preferences::getNotifyString() { return notifyList.join(" "); }
+bool Preferences::addNotify(const QString& newPattern)
+{
+  // don't add duplicates
+  if(notifyList.findIndex(newPattern)==-1)
+  {
+    notifyList.append(newPattern);
+    return true;
+  }
+  return false;
+}
+bool Preferences::removeNotify(const QString& pattern) { return (notifyList.remove(pattern)); }
 
 QStringList Preferences::getButtonList() { return buttonList; }
 
 // Default identity functions
 void Preferences::addIdentity(Identity* identity) { identityList.append(identity); }
+void Preferences::removeIdentity(Identity* identity) { identityList.remove(identity); }
 void Preferences::clearIdentityList() { identityList.clear(); }
 QPtrList<Identity> Preferences::getIdentityList() { return identityList; }
 
@@ -350,6 +371,10 @@ QStringList Preferences::getNicknameList() { return identityList.at(0)->getNickn
 void Preferences::setNickname(int index,const QString &newName) { identityList.at(0)->setNickname(index,newName); }
 void Preferences::setNicknameList(const QStringList &newList) { identityList.at(0)->setNicknameList(newList); }
 
+// FIXME: use per-identity codec setting
+void Preferences::setCodec(const QString &newCodec) { codec=newCodec; }
+QString Preferences::getCodec() { return codec; }
+
 void Preferences::setBlinkingTabs(bool blink) { blinkingTabs=blink; }
 bool Preferences::getBlinkingTabs() { return blinkingTabs; }
 
@@ -416,7 +441,7 @@ void Preferences::setVoiceLedColor(int passed_color)    { voiceLedColor=passed_c
 void Preferences::setNoRightsLedColor(int passed_color) { noRightsLedColor=passed_color; }
 
 // Geometry functions
-QSize Preferences::getServerWindowSize()  { return serverWindowSize; };
+QSize Preferences::getMainWindowSize()         { return mainWindowSize; };
 QSize Preferences::getHilightSize()            { return hilightSize; };
 QSize Preferences::getButtonsSize()            { return buttonsSize; };
 QSize Preferences::getIgnoreSize()             { return ignoreSize; };
@@ -425,7 +450,7 @@ QSize Preferences::getNicksOnlineSize()        { return nicksOnlineSize; };
 QSize Preferences::getNicknameSize()           { return nicknameSize; };
 QSize Preferences::getColorConfigurationSize() { return colorConfigurationSize; }
 
-void Preferences::setServerWindowSize(QSize newSize)       { serverWindowSize=newSize; };
+void Preferences::setMainWindowSize(QSize newSize)         { mainWindowSize=newSize; };
 void Preferences::setHilightSize(QSize newSize)            { hilightSize=newSize; };
 void Preferences::setButtonsSize(QSize newSize)            { buttonsSize=newSize; };
 void Preferences::setIgnoreSize(QSize newSize)             { ignoreSize=newSize; };
@@ -470,9 +495,6 @@ bool Preferences::getShowServerList() { return showServerList; }
 void Preferences::setChannelSplitter(QValueList<int> sizes) { channelSplitter=sizes; }
 QValueList<int> Preferences::getChannelSplitter() { return channelSplitter; }
 
-void Preferences::setCodec(const QString &newCodec) { codec=newCodec; }
-QString Preferences::getCodec() { return codec; }
-
 void Preferences::setChannelDoubleClickAction(const QString &action) { channelDoubleClickAction=action; }
 QString Preferences::getChannelDoubleClickAction() { return channelDoubleClickAction; }
 
@@ -486,4 +508,24 @@ int Preferences::getSpacing() { return spacing; }
 void Preferences::setMargin(int newMargin) { margin=newMargin; }
 int Preferences::getMargin() { return margin; }
 
+void Preferences::setUseParagraphSpacing(bool state) { useParagraphSpacing=state; }
+bool Preferences::getUseParagraphSpacing() { return useParagraphSpacing; }
+void Preferences::setParagraphSpacing(int newSpacing) { paragraphSpacing=newSpacing; }
+int Preferences::getParagraphSpacing() { return paragraphSpacing; }
+
+// sorting stuff
+void Preferences::setOpValue(int value)              { opValue=value; }
+void Preferences::setVoiceValue(int value)           { voiceValue=value; }
+void Preferences::setNoRightsValue(int value)        { noRightsValue=value; }
+
+int Preferences::getOpValue()                        { return opValue; }
+int Preferences::getVoiceValue()                     { return voiceValue; }
+int Preferences::getNoRightsValue()                  { return noRightsValue; }
+
+void Preferences::setSortCaseInsensitive(bool state) { sortCaseInsensitive=state; }
+void Preferences::setSortByStatus(bool state)        { sortByStatus=state; }
+
+bool Preferences::getSortCaseInsensitive()           { return sortCaseInsensitive; }
+bool Preferences::getSortByStatus()                  { return sortByStatus; }
+
 #include "preferences.moc"
