@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: preferences.h,v 1.46 2003/03/21 16:56:37 eisfuchs Exp $
+  $Id: preferences.h,v 1.52 2003/05/09 12:25:53 eisfuchs Exp $
 */
 
 #ifndef PREFERENCES_H
@@ -50,12 +50,12 @@ class Preferences : public QObject
     Preferences();
     ~Preferences();
 
-    int serverWindowToolBarPos;
-    int serverWindowToolBarStatus;
-    int serverWindowToolBarIconText;
-    int serverWindowToolBarIconSize;
-    bool serverWindowStatusBarStatus;
-    bool serverWindowMenuBarStatus;
+    int mainWindowToolBarPos;
+    int mainWindowToolBarStatus;
+    int mainWindowToolBarIconText;
+    int mainWindowToolBarIconSize;
+    bool mainWindowStatusBarStatus;
+    bool mainWindowMenuBarStatus;
 
     int addServer(const QString& serverString);
     void removeServer(int id);
@@ -107,8 +107,21 @@ class Preferences : public QObject
     void setCloseButtonsOnTabs(bool state);
     bool getCloseButtonsOnTabs();
 
+    // sorting stuff
+    bool getSortByStatus();
+    void setSortByStatus(bool state);
+    bool getSortCaseInsensitive();
+    void setSortCaseInsensitive(bool state);
+    // more sorting stuff
+    int getOpValue();
+    void setOpValue(int value);
+    int getVoiceValue();
+    void setVoiceValue(int value);
+    int getNoRightsValue();
+    void setNoRightsValue(int value);
+
     // Geometry functions
-    QSize getServerWindowSize();
+    QSize getMainWindowSize();
     QSize getHilightSize();
     QSize getButtonsSize();
     QSize getIgnoreSize();
@@ -116,7 +129,7 @@ class Preferences : public QObject
     QSize getNicksOnlineSize();
     QSize getNicknameSize();
     QSize getColorConfigurationSize();
-    void setServerWindowSize(QSize newSize);
+    void setMainWindowSize(QSize newSize);
     void setHilightSize(QSize newSize);
     void setButtonsSize(QSize newSize);
     void setIgnoreSize(QSize newSize);
@@ -131,7 +144,9 @@ class Preferences : public QObject
     void setUseNotify(bool use);
     QStringList getNotifyList();
     QString getNotifyString();
-    void setNotifyList(const QStringList &newList);
+    void setNotifyList(const QStringList& newList);
+    bool addNotify(const QString& newPattern);
+    bool removeNotify(const QString& pattern);
 
     QPtrList<Highlight> getHilightList();
     void setHilightList(QPtrList<Highlight> newList);
@@ -158,6 +173,7 @@ class Preferences : public QObject
     void setIgnoreList(QPtrList<Ignore> newList);
 
     void addIdentity(Identity* identity);
+    void removeIdentity(Identity* identity);
     void clearIdentityList();
     QPtrList<Identity> getIdentityList();
     const Identity *getIdentityByName(const QString& name);
@@ -264,6 +280,11 @@ class Preferences : public QObject
     void setMargin(int newMargin);
     int getMargin();
 
+    void setUseParagraphSpacing(bool state);
+    bool getUseParagraphSpacing();
+    void setParagraphSpacing(int newSpacing);
+    int getParagraphSpacing();
+    
   signals:
     void requestServerConnection(int number);
     void requestSaveOptions();
@@ -328,7 +349,7 @@ class Preferences : public QObject
     QString textViewBackground;
 
     // Geometries
-    QSize serverWindowSize;
+    QSize mainWindowSize;
     QSize buttonsSize;
     QSize hilightSize;
     QSize ignoreSize;
@@ -341,6 +362,17 @@ class Preferences : public QObject
     int spacing;
     int margin;
 
+    // sorting stuff
+    bool sortByStatus;
+    bool sortCaseInsensitive;
+    // more sorting stuff
+    int opValue;
+    int voiceValue;
+    int noRightsValue;
+
+    bool useParagraphSpacing;
+    int paragraphSpacing;
+
     QFont textFont;
     QFont listFont;
 
