@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: prefspageappearance.h,v 1.10 2003/03/21 20:27:24 eisfuchs Exp $
+  $Id: prefspageappearance.h,v 1.13 2003/04/27 19:01:55 eisfuchs Exp $
 */
 
 #ifndef PREFSPAGEAPPEARANCE_H
@@ -21,6 +21,8 @@
 #include <qcheckbox.h>
 #include <qspinbox.h>
 
+#include <klistview.h>
+
 #include "prefspage.h"
 
 /*
@@ -44,10 +46,21 @@ class PrefsPageAppearance : public PrefsPage
     void showCloseButtonsChanged(int state);
     void formatChanged(const QString& newFormat);
     void encodingChanged(int newEncodingIndex);
+
     void useSpacingChanged(int state);
     void spacingChanged(int newSpacing);
     void marginChanged(int newMargin);
 
+    void useParagraphSpacingChanged(int state);
+    void paragraphSpacingChanged(int newSpacing);
+
+    void sortByStatusChanged(int state);
+    void sortCaseInsensitiveChanged(int state);
+    void sortingOrderChanged();
+
+    void moveUp();
+    void moveDown();
+
   protected:
     void updateFonts();
 
@@ -65,9 +78,14 @@ class PrefsPageAppearance : public PrefsPage
 
     QLabel* spacingLabel;
     QLabel* marginLabel;
-    
+
     QSpinBox* spacing;
     QSpinBox* margin;
+
+    QCheckBox* useParagraphSpacingCheck;
+    QSpinBox* paragraphSpacingSpin;
+
+    KListView* sortingOrder;
 };
 
 #endif
