@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: prefspagegeneralsettings.cpp,v 1.10 2003/03/23 14:33:31 eisfuchs Exp $
+  $Id: prefspagegeneralsettings.cpp,v 1.11 2003/03/25 09:24:43 eisfuchs Exp $
 */
 
 #include <qlayout.h>
@@ -75,7 +75,7 @@ PrefsPageGeneralSettings::PrefsPageGeneralSettings(QFrame* newParent,Preferences
   bringToFrontCheck->setChecked(preferences->getBringToFront());
   fixedMOTDCheck->setChecked(preferences->getFixedMOTD());
   beepCheck->setChecked(preferences->getBeep());
-  beepCheck->setChecked(preferences->getRawLog());
+  rawLogCheck->setChecked(preferences->getRawLog());
 
   QHBox* generalSpacer=new QHBox(parentFrame);
 
