@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: prefspageidentity.h,v 1.9 2003/02/24 18:18:51 eisfuchs Exp $
+  $Id: prefspageidentity.h,v 1.11 2003/05/09 12:25:53 eisfuchs Exp $
 */
 
 #ifndef PREFSPAGEIDENTITY_H
@@ -19,6 +19,7 @@
 
 #include <qcheckbox.h>
 #include <qlabel.h>
+#include <qpushbutton.h>
 
 #include <klineedit.h>
 #include <kcombobox.h>
@@ -57,9 +58,11 @@ class PrefsPageIdentity : public PrefsPage
     void unAwayMessageChanged(const QString& newMessage);
 
     void updateIdentity(int number);
-    void renameIdentity(const QString& newName);
+//    void renameIdentity(const QString& newName);
+    void renameIdentity();
 
     void addIdentity();
+    void removeIdentity();
 
   protected:
     QPtrList<Identity> identities;
@@ -86,6 +89,8 @@ class PrefsPageIdentity : public PrefsPage
     QCheckBox* showAwayMessageCheck;
     KLineEdit* awayInput;
     KLineEdit* unAwayInput;
+    
+    QPushButton* removeIdentityButton;
 };
 
 #endif
