@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: prefspagelog.cpp,v 1.5 2003/03/23 14:33:31 eisfuchs Exp $
+  $Id: prefspagelog.cpp,v 1.7 2003/05/10 20:12:45 eisfuchs Exp $
 */
 
 #include <qlabel.h>
@@ -27,11 +27,11 @@ PrefsPageLog::PrefsPageLog(QFrame* newParent,Preferences* newPreferences) :
   QGridLayout* logSettingsLayout=new QGridLayout(parentFrame,4,2,marginHint(),spacingHint(),"log_settings_layout");
 
   useLog=new QCheckBox(i18n("Enable logging"),parentFrame,"use_log_checkbox");
-  lowerLog=new QCheckBox(i18n("Use lower case logs"),parentFrame,"lower_log_checkbox");
+  lowerLog=new QCheckBox(i18n("Use lower case logfile names"),parentFrame,"lower_log_checkbox");
   logFollowsNick=new QCheckBox(i18n("Follow nick changes"),parentFrame,"follow_nickchanges_checkbox");
 
   QHBox* logPathBox=new QHBox(parentFrame);
-/*  QLabel* logPathLabel= */ new QLabel("Logfile path:",logPathBox);
+  new QLabel(i18n("Logfile path:"),logPathBox);
   logPathInput=new KLineEdit(preferences->getLogPath(),logPathBox,"log_path_input");
 
   useLog->setChecked(preferences->getLog());
