@@ -11,11 +11,10 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: query.cpp,v 1.25 2003/03/12 15:33:59 eisfuchs Exp $
+  $Id: query.cpp,v 1.36 2003/05/13 13:32:51 eisfuchs Exp $
 */
 
 #include <qhbox.h>
-#include <qtextcodec.h>
 
 #include <klocale.h>
 #include <kstddirs.h>
@@ -23,6 +22,7 @@
 
 #include "query.h"
 #include "konversationapplication.h"
+#include "ircinput.h"
 
 Query::Query(QWidget* parent) : ChatWindow(parent)
 {
@@ -50,10 +50,16 @@ Query::Query(QWidget* parent) : ChatWindow(parent)
   connect(queryInput,SIGNAL (returnPressed()),this,SLOT (queryTextEntered()) );
   connect(queryInput,SIGNAL (textPasted(QString)),this,SLOT (textPasted(QString)) );
 
-  connect(textView,SIGNAL (newText()),this,SLOT (newTextInView()) );
+  connect(queryInput,SIGNAL (pageUp()),getTextView(),SLOT (pageUp()) );
+  connect(queryInput,SIGNAL (pageDown()),getTextView(),SLOT (pageDown()) );
+  
+  connect(textView,SIGNAL (newText(const QString&)),this,SLOT (newTextInView(const QString&)) );
   connect(textView,SIGNAL (gotFocus()),this,SLOT (adjustFocus()) );
   connect(textView,SIGNAL (sendFile()),this,SLOT (sendFileMenu()) );
 
+
+  updateFonts();
+
   setLog(KonversationApplication::preferences.getLog());
 }
 
@@ -62,11 +68,6 @@ Query::~Query()
   kdDebug() << "Query::~Query(" << getName() << ")" << endl;
 }
 
-void Query::close()
-{
-  emit closed(this);
-}
-
 void Query::setName(const QString& newName)
 {
   ChatWindow::setName(newName);
@@ -94,10 +95,8 @@ void Query::queryTextEntered()
 
 void Query::sendQueryText(const QString& sendLine)
 {
-  QTextCodec* codec=QTextCodec::codecForLocale();
-  QCString line=codec->fromUnicode(sendLine);
-
-  QString output=filter.parse(server->getNickname(),line,getName());
+  // encoding stuff is done in Server()
+  QString output=filter.parse(server->getNickname(),sendLine,getName());
 
   if(!output.isEmpty())
   {
@@ -109,9 +108,9 @@ void Query::sendQueryText(const QString& sendLine)
   server->queue(filter.getServerOutput());
 }
 
-void Query::newTextInView()
+void Query::newTextInView(const QString& highlightColor)
 {
-  emit newText(this);
+  emit newText(this,highlightColor);
 }
 
 void Query::setHostmask(const QString& newHostmask)
@@ -136,7 +135,14 @@ void Query::textPasted(QString text)
   if(server)
   {
     QStringList multiline=QStringList::split('\n',text);
-    for(unsigned int index=0;index<multiline.count();index++) sendQueryText(multiline[index]);
+    for(unsigned int index=0;index<multiline.count();index++)
+    {
+      QString line=multiline[index];
+      QString cChar(KonversationApplication::preferences.getCommandChar());
+      // make sure that lines starting with command char get escaped
+      if(line.startsWith(cChar)) line=cChar+line;
+      sendQueryText(line);
+    }
   }
 }
 
@@ -150,4 +156,12 @@ void Query::sendFileMenu()
   emit sendFile(getName());
 }
 
+QString Query::getTextInLine() { return queryInput->text(); }
+
+void Query::closeYourself()
+{
+  server->removeQuery(this);
+}
+
+
 #include "query.moc"
