@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: query.h,v 1.16 2003/03/12 15:33:59 eisfuchs Exp $
+  $Id: query.h,v 1.20 2003/05/13 13:32:51 eisfuchs Exp $
 */
 
 #ifndef QUERY_H
@@ -21,9 +21,9 @@
 #include <qvbox.h>
 #include <qiconset.h>
 #include <qcheckbox.h>
+#include <qlineedit.h>
 
 #include "chatwindow.h"
-#include "ircinput.h"
 
 /*
   @author Dario Abatianni
@@ -31,6 +31,9 @@
 
 /* TODO: Idle counter to close query after XXX minutes of inactivity */
 /* TODO: Use /USERHOST to check if queries are still valid */
+
+class IRCInput;
+
 class Query : public ChatWindow
 {
   Q_OBJECT
@@ -42,10 +45,11 @@ class Query : public ChatWindow
     void setName(const QString& newName);
     void setHostmask(const QString& newHostmask);
     void updateFonts();
+    QString getTextInLine();
+    void closeYourself();
 
   signals:
-    void newText(QWidget* query);
-    void closed(Query* query);
+    void newText(QWidget* query,const QString& highlightColor);
     void sendFile(const QString& recipient);
 
   public slots:
@@ -55,8 +59,7 @@ class Query : public ChatWindow
   protected slots:
     void queryTextEntered();
     void sendFileMenu();
-    void newTextInView();
-    void close();
+    void newTextInView(const QString& highlightColor);
     // connected to IRCInput::textPasted() - used to handle large/multiline pastes
     void textPasted(QString text);
 
