@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: quickbuttonsdialog.cpp,v 1.10 2003/03/23 14:33:31 eisfuchs Exp $
+  $Id: quickbuttonsdialog.cpp,v 1.11 2003/05/12 11:59:43 eisfuchs Exp $
 */
 
 #include <qlayout.h>
@@ -25,7 +25,7 @@
 #include "quickbuttonsdialog.h"
 
 QuickButtonsDialog::QuickButtonsDialog(QStringList buttonList,QSize size):
-                    KDialogBase(0,"quickbuttonsdialog",false,i18n("Edit quick buttons"),
+                    KDialogBase(static_cast<QWidget*>(0),"quickbuttonsdialog",false,i18n("Edit quick buttons"),
                                 KDialogBase::Ok | KDialogBase::Apply | KDialogBase::Cancel,
                                 KDialogBase::Ok,true)
 {
