@@ -11,12 +11,14 @@
   copyright: (C) 2003 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: rawlog.cpp,v 1.1 2003/03/18 14:34:57 eisfuchs Exp $
+  $Id: rawlog.cpp,v 1.3 2003/04/24 22:51:52 eisfuchs Exp $
 */
 
 #include <klocale.h>
+#include <kdebug.h>
 
 #include "rawlog.h"
+#include "konversationapplication.h"
 
 RawLog::RawLog(QWidget* parent) : ChatWindow(parent)
 {
@@ -34,4 +36,17 @@ void RawLog::adjustFocus()
   // do nothing, just implement this to make abstract functions work
 }
 
+void RawLog::updateFonts()
+{
+  getTextView()->setFont(KonversationApplication::preferences.getTextFont());
+  getTextView()->setPaper(QColor("#"+KonversationApplication::preferences.getTextViewBackground()));
+}
+
+void RawLog::closeYourself()
+{
+  // make the server delete us so server can reset the pointer to us
+  server->closeRawLog();
+  kdDebug() << "RawLog::closeYourself()" << endl;
+}
+
 #include "rawlog.moc"
