@@ -11,7 +11,7 @@
   copyright: (C) 2003 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: rawlog.h,v 1.1 2003/03/18 14:34:57 eisfuchs Exp $
+  $Id: rawlog.h,v 1.3 2003/04/24 22:51:52 eisfuchs Exp $
 */
 
 #ifndef _RAWLOG_H_
@@ -30,9 +30,12 @@ class RawLog : public ChatWindow
   public:
     RawLog(QWidget* parent);
     ~RawLog();
-  
+
+    void closeYourself();
+
   public slots:
     virtual void adjustFocus();
+    void updateFonts();
 };
 
 #endif
