@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: server.cpp,v 1.73 2003/03/23 14:33:31 eisfuchs Exp $
+  $Id: server.cpp,v 1.102 2003/05/25 17:41:05 eisfuchs Exp $
 */
 
 #include <unistd.h>
@@ -20,6 +20,7 @@
 #include <qhostaddress.h>
 #include <qtextcodec.h>
 
+#include <kapp.h>
 #include <klocale.h>
 #include <kdebug.h>
 #include <kfiledialog.h>
@@ -27,41 +28,52 @@
 #include "server.h"
 #include "query.h"
 #include "channel.h"
-#include "serverwindow.h"
 #include "ircserversocket.h"
 #include "konversationapplication.h"
+#include "dccpanel.h"
 #include "dcctransfer.h"
 #include "dccrecipientdialog.h"
+#include "nick.h"
+#include "konversationmainwindow.h"
+#include "statuspanel.h"
+#include "rawlog.h"
+#include "channellistpanel.h"
 
-Server::Server(int id)
+Server::Server(KonversationMainWindow* newMainWindow,int id)
 {
-  setName("server");
-  QStringList serverEntry=QStringList::split(',',KonversationApplication::preferences.getServerById(id),true);
-  setIdentity(KonversationApplication::preferences.getIdentityByName(serverEntry[7]));
-
+  identity=0;
   tryNickNumber=0;
   checkTime=0;
   reconnectCounter=0;
+  currentLag=0;
+  rawLog=0;
+  channelListPanel=0;
+
+  QStringList serverEntry=QStringList::split(',',KonversationApplication::preferences.getServerById(id),true);
+  setIdentity(KonversationApplication::preferences.getIdentityByName(serverEntry[7]));
+
+  setName(QString("server_"+serverEntry[1]).ascii());
+
+  setMainWindow(newMainWindow);
+
+  serverName=serverEntry[1];
+  serverPort=serverEntry[2].toInt();
+  serverKey=serverEntry[3];
 
   resolver.setRecipient(this);
   installEventFilter(this);
 
   lastDccDir=QString::null;
 
-  serverWindow=new ServerWindow(this);
-  setNickname(identity->getNickname(tryNickNumber));
-  bot=identity->getBot();
-  botPassword=identity->getPassword();
-  serverWindow->setIdentity(getIdentity());
-  serverWindow->show();
-
-  serverName=serverEntry[1];
-  serverPort=serverEntry[2].toInt();
-  serverKey=serverEntry[3];
+  statusView=getMainWindow()->addStatusView(this);
+  if(KonversationApplication::preferences.getRawLog()) addRawLog(false);
+  setNickname(getIdentity()->getNickname(tryNickNumber));
+  bot=getIdentity()->getBot();
+  botPassword=getIdentity()->getPassword();
 
   serverSocket.setAddress(serverName,serverPort);
 
-  if(serverEntry[4] && !serverEntry[4].isEmpty())
+  if(!serverEntry[4].isEmpty())
   {
     setAutoJoin(true);
     setAutoJoinChannel(serverEntry[4]);
@@ -80,7 +92,7 @@ Server::Server(int id)
   completeQueryPosition=0;
 
   inputFilter.setServer(this);
-  outputFilter.setIdentity(identity);
+  outputFilter.setIdentity(getIdentity());
 
   notifyTimer.setName("notifyTimer");
   incomingTimer.setName("incomingTimer");
@@ -93,9 +105,9 @@ Server::Server(int id)
                    this,SLOT   (addQuery(const QString&,const QString&)) );
   connect(&outputFilter,SIGNAL (requestDccSend()),
                    this,SLOT   (requestDccSend()) );
-  connect(&outputFilter,SIGNAL (requestDccSend(const QString &)),
-                   this,SLOT   (requestDccSend(const QString &)) );
-  
+  connect(&outputFilter,SIGNAL (requestDccSend(const QString&)),
+                   this,SLOT   (requestDccSend(const QString&)) );
+
   connect(&notifyTimer,SIGNAL(timeout()),
                   this,SLOT  (notifyTimeout()) );
   connect(&notifyCheckTimer,SIGNAL(timeout()),
@@ -103,47 +115,67 @@ Server::Server(int id)
 
   connect(&inputFilter,SIGNAL(welcome()),
                   this,SLOT  (connectionEstablished()) );
-  connect(&inputFilter,SIGNAL(notifyResponse(const QString &)),
-                  this,SLOT  (notifyResponse(const QString &)) );
-  connect(&inputFilter,SIGNAL(addDccGet(const QString &, const QStringList &)),
-                  this,SLOT  (addDccGet(const QString &, const QStringList &)) );
-  connect(&inputFilter,SIGNAL(resumeDccGetTransfer(const QString &, const QStringList &)),
-                  this,SLOT  (resumeDccGetTransfer(const QString &, const QStringList &)) );
-  connect(&inputFilter,SIGNAL(resumeDccSendTransfer(const QString &, const QStringList &)),
-                  this,SLOT  (resumeDccSendTransfer(const QString &, const QStringList &)) );
+  connect(&inputFilter,SIGNAL(notifyResponse(const QString&)),
+                  this,SLOT  (notifyResponse(const QString&)) );
+  connect(&inputFilter,SIGNAL(addDccGet(const QString&, const QStringList&)),
+                  this,SLOT  (addDccGet(const QString&, const QStringList&)) );
+  connect(&inputFilter,SIGNAL(resumeDccGetTransfer(const QString&, const QStringList&)),
+                  this,SLOT  (resumeDccGetTransfer(const QString&, const QStringList&)) );
+  connect(&inputFilter,SIGNAL(resumeDccSendTransfer(const QString&, const QStringList&)),
+                  this,SLOT  (resumeDccSendTransfer(const QString&, const QStringList&)) );
+  connect(&inputFilter,SIGNAL(userhost(const QString&,const QString&,bool,bool)),
+                  this,SLOT  (userhost(const QString&,const QString&,bool,bool)) );
+  connect(&inputFilter,SIGNAL(topicAuthor(const QString&,const QString&)),
+                  this,SLOT  (setTopicAuthor(const QString&,const QString&)) );
+  connect(&inputFilter,SIGNAL(addChannelListPanel()),
+                  this,SLOT  (addChannelListPanel()) );
 
-  connect(this,SIGNAL(serverLag(int)),serverWindow,SLOT(updateLag(int)) );
-  connect(this,SIGNAL(tooLongLag(int)),serverWindow,SLOT(tooLongLag(int)) );
-  connect(this,SIGNAL(resetLag()),serverWindow,SLOT(resetLag()) );
-  connect(this,SIGNAL(addDccPanel()),serverWindow,SLOT(addDccPanel()) );
-  connect(this,SIGNAL(closeDccPanel()),serverWindow,SLOT(closeDccPanel()) );
+
+  connect(this,SIGNAL(serverLag(int)),statusView,SLOT(updateLag(int)) );
+  connect(this,SIGNAL(serverLag(Server*,int)),getMainWindow(),SLOT(updateLag(Server*,int)) );
+  connect(this,SIGNAL(tooLongLag(Server*,int)),getMainWindow(),SLOT(tooLongLag(Server*,int)) );
+  connect(this,SIGNAL(resetLag()),getMainWindow(),SLOT(resetLag()) );
+  connect(this,SIGNAL(addDccPanel()),getMainWindow(),SLOT(addDccPanel()) );
+  connect(this,SIGNAL(addKonsolePanel()),getMainWindow(),SLOT(addKonsolePanel()) );
 
   connect(&serverSocket,SIGNAL (connectionSuccess())  ,this,SLOT (ircServerConnectionSuccess()) );
   connect(&serverSocket,SIGNAL (connectionFailed(int)),this,SLOT (broken(int)) );
   connect(&serverSocket,SIGNAL (readyRead()),this,SLOT (incoming()) );
   connect(&serverSocket,SIGNAL (readyWrite()),this,SLOT (send()) );
   connect(&serverSocket,SIGNAL (closed(int)),this,SLOT (broken(int)) );
+
+  connect(getMainWindow(),SIGNAL(prefsChanged()),KonversationApplication::kApplication(),SLOT(saveOptions()));
+  connect(getMainWindow(),SIGNAL(openPrefsDialog()),KonversationApplication::kApplication(),SLOT(openPrefsDialog()));
 }
 
 Server::~Server()
 {
   kdDebug() << "Server::~Server()" << endl;
 
+  // clear nicks online
+  emit nicksNowOnline(this,QStringList());
   // Make sure no signals get sent to a soon to be dying Server Window
   serverSocket.blockSignals(true);
   // Send out the last messages (usually the /QUIT)
   serverSocket.enableWrite(true);
   send();
 
+  closeRawLog();
+  closeChannelListPanel();
+  channelList.setAutoDelete(true);
+  while(channelList.removeFirst());
+  queryList.setAutoDelete(true);
+  while(queryList.removeFirst());
+
   // notify KonversationApplication that this server is gone
   emit deleted(this);
-  
-  delete serverWindow;
 }
 
 QString Server::getServerName() { return serverName; }
 int Server::getPort() { return serverPort; }
 
+int Server::getLag() { return currentLag; }
+
 bool Server::getAutoJoin() { return autoJoin; }
 void Server::setAutoJoin(bool on) { autoJoin=on; }
 
@@ -169,8 +201,7 @@ void Server::connectToIRCServer()
   else
   {
     // (re)connect. Autojoin will be done by the input filter
-    serverWindow->appendToStatus(i18n("Info"),i18n("Looking for server %1 ...").arg(serverSocket.host()));
-
+    statusView->appendServerMessage(i18n("Info"),i18n("Looking for server %1 ...").arg(serverSocket.host()));
     // QDns is broken, so don't use async lookup, use own threaded class instead
     resolver.setSocket(&serverSocket);
     resolver.start();
@@ -189,7 +220,7 @@ bool Server::eventFilter(QObject* parent,QEvent* event)
 
 void Server::lookupFinished()
 {
-  serverWindow->appendToStatus(i18n("Info"),i18n("Server found, connecting ..."));
+  statusView->appendServerMessage(i18n("Info"),i18n("Server found, connecting ..."));
   serverSocket.startAsyncConnect();
 }
 
@@ -197,16 +228,15 @@ void Server::ircServerConnectionSuccess()
 {
   reconnectCounter=0;
 
-  connect(this,SIGNAL (nicknameChanged(const QString&)),serverWindow,SLOT (setNickname(const QString&)) );
-
-  serverWindow->appendToStatus(i18n("Info"),i18n("Connected! Logging in ..."));
+  connect(this,SIGNAL (nicknameChanged(const QString&)),statusView,SLOT (setNickname(const QString&)) );
+  statusView->appendServerMessage(i18n("Info"),i18n("Connected! Logging in ..."));
 
   QString connectString="USER " +
                         identity->getIdent() +
                         " 8 * :" +  // 8 = +i; 4 = +w
                         identity->getRealName();
 
-  if (serverKey) queue("PASS "+serverKey);
+  if(!serverKey.isEmpty()) queue("PASS "+serverKey);
   queue("NICK "+getNickname());
   queue(connectString);
 
@@ -223,17 +253,18 @@ void Server::broken(int state)
 
   kdDebug() << "Connection broken (Socket fd " << serverSocket.fd() << ") " << state << "!" << endl;
 
+  // clear nicks online
+  emit nicksNowOnline(this,QStringList());
+
   // TODO: Close all queries and channels!
   //       Or at least make sure that all gets reconnected properly
-
   if(autoReconnect && !getDeliberateQuit())
   {
-    serverWindow->appendToStatus(i18n("Error"),i18n("Connection to Server %1 lost. Trying to reconnect.").arg(serverName));
-
+    statusView->appendServerMessage(i18n("Error"),i18n("Connection to Server %1 lost. Trying to reconnect.").arg(serverName));
     // TODO: Make retry counter configurable
     if(++reconnectCounter==10)
     {
-      serverWindow->appendToStatus(i18n("Error"),i18n("Connection to Server %1 failed.").arg(serverName));
+      statusView->appendServerMessage(i18n("Error"),i18n("Connection to Server %1 failed.").arg(serverName));
       reconnectCounter=0;
     }
     else
@@ -242,7 +273,7 @@ void Server::broken(int state)
   }
   else
   {
-    serverWindow->appendToStatus(i18n("Error"),i18n("Connection to Server %1 closed.").arg(serverName));
+    statusView->appendServerMessage(i18n("Error"),i18n("Connection to Server %1 closed.").arg(serverName));
   }
 }
 
@@ -256,11 +287,41 @@ void Server::connectionEstablished()
     queue("PRIVMSG "+bot+" :identify "+botPassword);
 }
 
+void Server::quitServer()
+{
+  QString command(KonversationApplication::preferences.getCommandChar()+"QUIT");
+  outputFilter.parse(getNickname(),command,QString::null);
+  queue(outputFilter.getServerOutput());
+}
+
+void Server::notifyAction(const QString& nick)
+{
+  // parse wildcards (toParse,nickname,channelName,nickList,queryName,parameter)
+  QString out=parseWildcards(KonversationApplication::preferences.getNotifyDoubleClickAction(),
+                             getNickname(),
+                             QString::null,
+                             QString::null,
+                             nick,
+                             QString::null,
+                             QString::null);
+  // Send all strings, one after another
+  QStringList outList=QStringList::split('\n',out);
+  for(unsigned int index=0;index<outList.count();index++)
+  {
+    outputFilter.parse(getNickname(),outList[index],QString::null);
+    queue(outputFilter.getServerOutput());
+  } // endfor
+}
+
 void Server::notifyResponse(const QString& nicksOnline)
 {
   // We received a 303 or "PONG :LAG" notify message, so calculate server lag
   int lag=notifySent.elapsed();
+  currentLag=lag;
+  // inform status panel ...
   emit serverLag(lag);
+  // ... and main window
+  emit serverLag(this,lag);
   // Stop check timer
   notifyCheckTimer.stop();
 
@@ -279,7 +340,7 @@ void Server::notifyResponse(const QString& nicksOnline)
     {
       if(notifyLowerCache.find(nickLowerList[index])==notifyLowerCache.end())
       {
-        serverWindow->appendToFrontmost(i18n("Notify"),i18n("%1 is online.").arg(nickList[index]));
+        getMainWindow()->appendToFrontmost(i18n("Notify"),i18n("%1 is online (%2).").arg(nickList[index]).arg(getServerName()),statusView);
       }
     }
 
@@ -288,13 +349,13 @@ void Server::notifyResponse(const QString& nicksOnline)
     {
       if(nickLowerList.find(notifyLowerCache[index])==nickLowerList.end())
       {
-        serverWindow->appendToFrontmost(i18n("Notify"),i18n("%1 went offline.").arg(notifyCache[index]));
+        getMainWindow()->appendToFrontmost(i18n("Notify"),i18n("%1 went offline. (%2)").arg(notifyCache[index]).arg(getServerName()),statusView);
       }
     }
 
     // Finally copy the new ISON list with correct case to our notify cache
     notifyCache=nickList;
-    emit nicksNowOnline(nickList);
+    emit nicksNowOnline(this,nickList);
   }
   // Next round
   startNotifyTimer();
@@ -341,10 +402,15 @@ void Server::notifyTimeout()
   startNotifyCheckTimer();
 }
 
+// waiting too long for 303 response
 void Server::notifyCheckTimeout()
 {
   checkTime+=500;
-  if(isConnected()) emit tooLongLag(checkTime);
+  if(isConnected())
+  {
+    currentLag=checkTime;
+    emit tooLongLag(this,checkTime);
+  }
 }
 
 QString Server::getAutoJoinCommand()
@@ -352,7 +418,7 @@ QString Server::getAutoJoinCommand()
   // Multichannel joins
   QStringList channels=QStringList::split(' ',autoJoinChannel);
   QStringList keys=QStringList::split(' ',autoJoinChannelKey);
-  
+
   QString autoString("JOIN "+channels.join(",")+" "+keys.join(","));
 
   return autoString;
@@ -381,7 +447,7 @@ void Server::processIncomingData()
 
     inputBuffer=inputBuffer.mid(pos+1);
 
-    getServerWindow()->appendToRaw(line);
+    if(rawLog) rawLog->appendRaw(line);
     inputFilter.parseLine(line);
   }
 }
@@ -395,17 +461,20 @@ void Server::incoming()
 
   buffer[len]=0;
 
-  inputBuffer+=buffer;
+  // convert IRC ascii data to selected encoding
+  QTextCodec* codec=QTextCodec::codecForName(KonversationApplication::preferences.getCodec().ascii());
+  inputBuffer+=codec->toUnicode(buffer);
 
   if(len==0) broken(0);
 }
 
-void Server::queue(const QString &buffer)
+void Server::queue(const QString& buffer)
 {
   // Only queue lines if we are connected
   if(isConnected() && buffer.length())
   {
-    getServerWindow()->appendToRaw(buffer);
+    if(rawLog) rawLog->appendRaw(buffer);
+
     outputBuffer+=buffer;
     outputBuffer+="\n";
 
@@ -421,12 +490,29 @@ void Server::send()
     // To make lag calculation more precise, we reset the timer here
     if(outputBuffer.startsWith("ISON") ||
        outputBuffer.startsWith("PING LAG")) notifySent.start();
-    
+
     // Don't reconnect if we WANT to quit
     else if(outputBuffer.startsWith("QUIT")) setDeliberateQuit(true);
-    
+
     // TODO: Implement Flood-Protection here
-    write(serverSocket.fd(),outputBuffer,outputBuffer.length());
+
+    // wrap server socket into a stream
+    QTextStream serverStream(&serverSocket);
+
+    // init stream props
+    serverStream.setEncoding(QTextStream::Locale);
+    QString codecName=KonversationApplication::preferences.getCodec();
+    // convert encoded data to IRC ascii only when we don't have the same codec locally
+    if(QString(QTextCodec::codecForLocale()->name()).lower()!=codecName.lower())
+    {
+      serverStream.setCodec(QTextCodec::codecForName(codecName.ascii()));
+    }
+
+    serverStream << outputBuffer;
+
+    // detach server stream
+    serverStream.unsetDevice();
+
     serverSocket.enableWrite(false);
   }
 
@@ -472,25 +558,23 @@ void Server::setDeliberateQuit(bool on)
   deliberateQuit=on;
 }
 
-void Server::addQuery(const QString &nickname,const QString &hostmask)
+void Server::addQuery(const QString& nickname,const QString& hostmask)
 {
   // Only create new query object if there isn't already one with the same name
   Query* query=getQueryByName(nickname);
   if(!query)
   {
-    query=new Query(serverWindow->getWindowContainer());
-    query->setServer(this);
+    query=getMainWindow()->addQuery(this,nickname);
     query->setIdentity(getIdentity());
-    query->setName(nickname);
-    // Add new query pane to tabwidget
-    serverWindow->addView(query,0,nickname);
 
-    connect(query,SIGNAL (newText(QWidget*)),serverWindow,SLOT (newText(QWidget*)) );
-    connect(query,SIGNAL (closed(Query*)),this,SLOT (removeQuery(Query*)) );
     connect(query,SIGNAL (sendFile(const QString&)),this,SLOT (requestDccSend(const QString &)) );
     // Append query to internal list
     queryList.append(query);
   }
+
+  // try to get hostmask if there's none yet
+  if(hostmask.isEmpty()) requestUserhost(nickname);
+
   // Always set hostmask
   if(query) query->setHostmask(hostmask);
 }
@@ -507,6 +591,65 @@ void Server::closeChannel(const QString &name)
   queue(outputFilter.getServerOutput());
 }
 
+void Server::requestChannelList()
+{
+  inputFilter.setAutomaticRequest(true);
+  queue("LIST");
+}
+
+void Server::requestUserhost(const QString& nicks)
+{
+  inputFilter.setAutomaticRequest(true);
+  queue("USERHOST "+nicks);
+}
+
+void Server::requestBan(const QStringList& users,const QString& channel,const QString& a_option)
+{
+  QString hostmask;
+  QString banCommand;
+  QString option=a_option.lower();
+
+  Channel* targetChannel=getChannelByName(channel);
+
+  for(unsigned int index=0;index<users.count();index++)
+  {
+    // first, set the ban mask to the specified nick
+    QString mask=users[index];
+    // did we specify an option?
+    if(!option.isEmpty())
+    {
+      // try to find specified nick on the channel
+      Nick* targetNick=targetChannel->getNickByName(mask);
+      // if we found the nick try to find their hostmask
+      if(targetNick)
+      {
+        QString hostmask=targetNick->getHostmask();
+        // if we found the hostmask, add it to the ban mask
+        if(!hostmask.isEmpty())
+        {
+          mask=targetNick->getNickname()+"!"+hostmask;
+
+          // adapt ban mask to the option given
+          if(option=="host")
+            mask="*!*@*."+hostmask.section('.',1);
+          else if(option=="domain")
+            mask="*!*@"+hostmask.section('@',1);
+          else if(option=="userhost")
+            mask="*!"+hostmask.section('@',0,0)+"@*."+hostmask.section('.',1);
+          else if(option=="userdomain")
+            mask="*!"+hostmask.section('@',0,0)+"@"+hostmask.section('@',1);
+        }
+      }
+    }
+
+    outputFilter.execBan(mask,channel);
+
+    banCommand=outputFilter.getServerOutput();
+
+    queue(banCommand);
+  }
+}
+
 void Server::requestDccSend()
 {
   requestDccSend(QString::null);
@@ -516,7 +659,7 @@ void Server::requestDccSend(const QString &a_recipient)
 {
   QString recipient(a_recipient);
   // if we don't have a recipient yet, let the user select one
-  if(!recipient)
+  if(recipient.isEmpty())
   {
     QStringList nickList;
     Channel* lookChannel=channelList.first();
@@ -524,7 +667,7 @@ void Server::requestDccSend(const QString &a_recipient)
     // fill nickList with all nicks we know about
     while(lookChannel)
     {
-      QList<Nick> nicks=lookChannel->getNickList();
+      QPtrList<Nick> nicks=lookChannel->getNickList();
       Nick* lookNick=nicks.first();
       while(lookNick)
       {
@@ -542,15 +685,15 @@ void Server::requestDccSend(const QString &a_recipient)
       lookQuery=queryList.next();
     }
 
-    recipient=DccRecipientDialog::getNickname(getServerWindow(),nickList);
+    recipient=DccRecipientDialog::getNickname(getMainWindow(),nickList);
   }
   // do we have a recipient *now*?
-  if(recipient && !recipient.isEmpty())
+  if(!recipient.isEmpty())
   {
     QString fileName=KFileDialog::getOpenFileName(
                                                    lastDccDir,
                                                    QString::null,
-                                                   getServerWindow(),
+                                                   getMainWindow(),
                                                    i18n("Select file to send to %1").arg(recipient)
                                                  );
     if(!fileName.isEmpty())
@@ -581,7 +724,7 @@ void Server::addDccSend(const QString &recipient,const QString &fileName)
 
 //  kdDebug() << ip << endl;
 
-  DccTransfer* newDcc=new DccTransfer(serverWindow->getDccPanel()->getListView(),
+  DccTransfer* newDcc=new DccTransfer(getMainWindow()->getDccPanel()->getListView(),
                   DccTransfer::Send,
                   KonversationApplication::preferences.getDccPath(),
                   recipient,
@@ -605,15 +748,15 @@ void Server::addDccGet(const QString &sourceNick, const QStringList &dccArgument
   ip.setAddress(dccArguments[1].toULong());
 
   appendStatusMessage(i18n("DCC"),
-                      QString("%1 offers the file \"%2\" (%3 bytes) for download (%4:%5).")
+                      i18n("%1 offers the file \"%2\" (%3 bytes) for download (%4:%5).")
                               .arg(sourceNick)               // name
                               .arg(dccArguments[0])          // file
-                              .arg((dccArguments[3].isEmpty()) ? i18n("unknown") : dccArguments[3] )  // size
+                              .arg((dccArguments[3].isEmpty()) ? i18n("unknown number of") : dccArguments[3] ) // size
                               .arg(ip.toString())            // ip
                               .arg(dccArguments[2])          // port
                              );
 
-  DccTransfer* newDcc=new DccTransfer(serverWindow->getDccPanel()->getListView(),
+  DccTransfer* newDcc=new DccTransfer(getMainWindow()->getDccPanel()->getListView(),
                   DccTransfer::Get,
                   KonversationApplication::preferences.getDccPath(),
                   sourceNick,
@@ -630,6 +773,11 @@ void Server::addDccGet(const QString &sourceNick, const QStringList &dccArgument
   if(KonversationApplication::preferences.getDccAutoGet()) newDcc->startGet();
 }
 
+void Server::requestKonsolePanel()
+{
+  emit addKonsolePanel();
+}
+
 void Server::requestDccPanel()
 {
   emit addDccPanel();
@@ -659,12 +807,12 @@ void Server::dccResumeGetRequest(const QString &sender, const QString &fileName,
 void Server::resumeDccGetTransfer(const QString &sourceNick, const QStringList &dccArguments)
 {
   // Check if there actually is a transfer going on on that port
-  DccTransfer* dccTransfer=serverWindow->getDccPanel()->getTransferByPort(dccArguments[1],DccTransfer::ResumeGet);
+  DccTransfer* dccTransfer=getMainWindow()->getDccPanel()->getTransferByPort(dccArguments[1],DccTransfer::ResumeGet);
   if(!dccTransfer)
     // Check if there actually is a transfer going on with that name, could be behind a NAT
     // so the port number may get changed
     // mIRC substitutes this with "file.ext", so we have a problem here with mIRCs behind a NAT
-    dccTransfer=serverWindow->getDccPanel()->getTransferByName(dccArguments[0],DccTransfer::ResumeGet);
+    dccTransfer=getMainWindow()->getDccPanel()->getTransferByName(dccArguments[0],DccTransfer::ResumeGet);
 
   if(dccTransfer)
   {
@@ -682,12 +830,12 @@ void Server::resumeDccGetTransfer(const QString &sourceNick, const QStringList &
 void Server::resumeDccSendTransfer(const QString &recipient, const QStringList &dccArguments)
 {
   // Check if there actually is a transfer going on on that port
-  DccTransfer* dccTransfer=serverWindow->getDccPanel()->getTransferByPort(dccArguments[1],DccTransfer::Send);
+  DccTransfer* dccTransfer=getMainWindow()->getDccPanel()->getTransferByPort(dccArguments[1],DccTransfer::Send);
   if(!dccTransfer)
     // Check if there actually is a transfer going on with that name, could be behind a NAT
     // so the port number may get changed
     // mIRC substitutes this with "file.ext", so we have a problem here with mIRCs behind a NAT
-    dccTransfer=serverWindow->getDccPanel()->getTransferByName(dccArguments[0],DccTransfer::Send);
+    dccTransfer=getMainWindow()->getDccPanel()->getTransferByName(dccArguments[0],DccTransfer::Send);
 
   if(dccTransfer)
   {
@@ -727,9 +875,6 @@ QString Server::getNextQueryName()
 
 void Server::removeQuery(Query* query)
 {
-  // Remove query page from container
-  serverWindow->getWindowContainer()->removePage(query);
-
   // Traverse through list to find the query
   Query* lookQuery=queryList.first();
   while(lookQuery)
@@ -749,6 +894,12 @@ void Server::removeQuery(Query* query)
   delete query;
 }
 
+void Server::sendJoinCommand(const QString& name)
+{
+  outputFilter.parse(getNickname(),KonversationApplication::preferences.getCommandChar()+"JOIN "+name,QString::null);
+  queue(outputFilter.getServerOutput());
+}
+
 void Server::joinChannel(const QString &name, const QString &hostmask, const QString &/*key*/)
 {
   // Make sure to delete stale Channel on rejoin.
@@ -761,20 +912,14 @@ void Server::joinChannel(const QString &name, const QString &hostmask, const QSt
     delete channel;
   }
 
-  channel=new Channel(serverWindow->getWindowContainer());
-
-  channel->setServer(this);
+  channel=getMainWindow()->addChannel(this,name);
   channel->setIdentity(getIdentity());
-  channel->setName(name);
   channel->setNickname(getNickname());
   //channel->setKey(key);
 
-  serverWindow->addView(channel,1,name);
+  channelList.append(channel);
   channel->joinNickname(getNickname(),hostmask);
 
-  channelList.append(channel);
-  connect(channel,SIGNAL (newText(QWidget*)),serverWindow,SLOT (newText(QWidget*)) );
-  connect(channel,SIGNAL (prefsChanged()),serverWindow,SLOT (channelPrefsChanged()) );
   connect(channel,SIGNAL (sendFile()),this,SLOT (requestDccSend()) );
 }
 
@@ -795,12 +940,12 @@ void Server::updateChannelModeWidgets(const QString &channelName, char mode, con
   if(channel) channel->updateModeWidgets(mode,true,parameter);
 }
 
-void Server::updateChannelQuickButtons(QStringList newButtons)
+void Server::updateChannelQuickButtons()
 {
   Channel* channel=channelList.first();
   while(channel)
   {
-    channel->updateQuickButtons(newButtons);
+    channel->updateQuickButtons(KonversationApplication::preferences.getButtonList());
     channel=channelList.next();
   }
 }
@@ -824,12 +969,10 @@ void Server::updateFonts()
     query=queryList.next();
   }
 
-  // TODO: To be revised
-  if(serverWindow)
-  {
-    serverWindow->updateFonts();
-    emit repaintTabs();
-  }
+  statusView->updateFonts();
+  getMainWindow()->updateFonts();
+
+  if(rawLog) rawLog->updateFonts();
 }
 
 // TODO: Maybe use a Signal / Slot mechanism for these things?
@@ -854,7 +997,7 @@ void Server::setShowModeButtons(bool state)
   }
 }
 
-Channel* Server::getChannelByName(const char* name)
+Channel* Server::getChannelByName(const QString& name)
 {
   // Convert wanted channel name to lowercase
   QString wanted=name;
@@ -871,7 +1014,7 @@ Channel* Server::getChannelByName(const char* name)
   return 0;
 }
 
-Query* Server::getQueryByName(const char* name)
+Query* Server::getQueryByName(const QString& name)
 {
   // Convert wanted query name to lowercase
   QString wanted=name;
@@ -900,7 +1043,7 @@ void Server::nickJoinsChannel(const QString &channelName, const QString &nicknam
   if(outChannel) outChannel->joinNickname(nickname,hostmask);
 }
 
-void Server::addHostmaskToNick(const QString &sourceNick, const QString &sourceHostmask)
+void Server::addHostmaskToNick(const QString& sourceNick, const QString& sourceHostmask)
 {
   Channel* channel=channelList.first();
 
@@ -961,73 +1104,77 @@ void Server::renameNick(const QString &nickname, const QString &newNick)
     if(query->getName().lower()==nickname.lower())
     {
       query->setName(newNick);
-      serverWindow->getWindowContainer()->changeTab(query,newNick);
     }
     query=queryList.next();
   }
 }
 
-void Server::appendToChannel(const char* channel,const char* nickname,const char* message)
+void Server::userhost(const QString& nick,const QString& hostmask,bool /* away */ ,bool /* ircOp */)
+{
+  addHostmaskToNick(nick,hostmask);
+}
+
+void Server::appendToChannel(const QString& channel,const QString& nickname,const QString& message)
 {
   Channel* outChannel=getChannelByName(channel);
   if(outChannel) outChannel->append(nickname,message);
 }
 
-void Server::appendActionToChannel(const char* channel,const char* nickname,const char* message)
+void Server::appendActionToChannel(const QString& channel,const QString& nickname,const QString& message)
 {
   Channel* outChannel=getChannelByName(channel);
   if(outChannel) outChannel->appendAction(nickname,message);
 }
 
-void Server::appendServerMessageToChannel(const char* channel,const char* type,const char* message)
+void Server::appendServerMessageToChannel(const QString& channel,const QString& type,const QString& message)
 {
   Channel* outChannel=getChannelByName(channel);
   if(outChannel) outChannel->appendServerMessage(type,message);
 }
 
-void Server::appendCommandMessageToChannel(const char* channel,const char* command,const char* message)
+void Server::appendCommandMessageToChannel(const QString& channel,const QString& command,const QString& message)
 {
   Channel* outChannel=getChannelByName(channel);
   if(outChannel) outChannel->appendCommandMessage(command,message);
 }
 
-void Server::appendToQuery(const char* queryName,const char* message)
+void Server::appendToQuery(const QString& queryName,const QString& message)
 {
   Query* outQuery=getQueryByName(queryName);
   if(outQuery) outQuery->appendQuery(queryName,message);
   else kdWarning() << "Server::appendToQuery(" << queryName << "): Query not found!" << endl;
 }
 
-void Server::appendActionToQuery(const char* queryName,const char* message)
+void Server::appendActionToQuery(const QString& queryName,const QString& message)
 {
   Query* outQuery=getQueryByName(queryName);
   if(outQuery) outQuery->appendAction(queryName,message);
   else kdWarning() << "Server::appendActionToQuery(" << queryName << "): Query not found!" << endl;
 }
 
-void Server::appendServerMessageToQuery(const char* queryName,const char* type,const char* message)
+void Server::appendServerMessageToQuery(const QString& queryName,const QString& type,const QString& message)
 {
   Query* outQuery=getQueryByName(queryName);
   if(outQuery) outQuery->appendServerMessage(type,message);
   else kdWarning() << "Server::appendServerMessageToQuery(" << queryName << "): Query not found!" << endl;
 }
 
-void Server::appendCommandMessageToQuery(const char* queryName,const char* command,const char* message)
+void Server::appendCommandMessageToQuery(const QString& queryName,const QString& command,const QString& message)
 {
   Query* outQuery=getQueryByName(queryName);
   if(outQuery) outQuery->appendCommandMessage(command,message);
   else kdWarning() << "Server::appendCommandMessageToQuery(" << queryName << "): Query not found!" << endl;
 }
 
-void Server::appendStatusMessage(const char* type,const char* message)
+void Server::appendStatusMessage(const QString& type,const QString& message)
 {
-  serverWindow->appendToFrontmost(type,message);
+  getMainWindow()->appendToFrontmost(type,message,statusView);
 }
 
 void Server::setNickname(const QString &newNickname)
 {
   nickname=newNickname;
-  serverWindow->setNickname(newNickname);
+  statusView->setNickname(newNickname);
 }
 
 void Server::setChannelTopic(const QString &channel, const QString &newTopic)
@@ -1035,9 +1182,8 @@ void Server::setChannelTopic(const QString &channel, const QString &newTopic)
   Channel* outChannel=getChannelByName(channel);
   if(outChannel)
   {
-    QTextCodec* codec=QTextCodec::codecForName(KonversationApplication::preferences.getCodec());
-    QString topic=codec->toUnicode(newTopic);
-    outChannel->setTopic(topic);
+    // encoding stuff is done in send()
+    outChannel->setTopic(newTopic);
   }
 }
 
@@ -1046,12 +1192,20 @@ void Server::setChannelTopic(const QString& nickname, const QString &channel, co
   Channel* outChannel=getChannelByName(channel);
   if(outChannel)
   {
-    QTextCodec* codec=QTextCodec::codecForName(KonversationApplication::preferences.getCodec());
-    QString topic=codec->toUnicode(newTopic);
+    // encoding stuff is done in send()
     outChannel->setTopic(nickname,newTopic);
   }
 }
 
+void Server::setTopicAuthor(const QString& channel,const QString& author)
+{
+  Channel* outChannel=getChannelByName(channel);
+  if(outChannel)
+  {
+    outChannel->setTopicAuthor(author);
+  }
+}
+
 bool Server::isNickname(const QString &compare)
 {
   return (nickname==compare);
@@ -1072,17 +1226,17 @@ QString Server::parseWildcards(const QString &toParse, const QString &nickname,
   // TODO: parameter handling.
   //       since parameters are not functional yet
 
-  // cut button name from definition
-  QString out(toParse.mid(toParse.find(',')+1));
+  // make a copy to work with
+  QString out(toParse);
   // define default separator and regular expression for definition
   QString separator(" ");
   QRegExp separatorRegExp("%s[^%]*%");
 
-  int pos;
   // separator definition found?
-  pos=out.find(separatorRegExp);
+  int pos=out.find(separatorRegExp);
   if(pos!=-1)
   {
+    // TODO: This could be better done with .cap() and proper RegExp ...
     // skip "%s" at the beginning
     pos+=2;
     // copy out all text to the next "%" as new separator
@@ -1091,16 +1245,15 @@ QString Server::parseWildcards(const QString &toParse, const QString &nickname,
     out.replace(separatorRegExp, QString::null);
   }
 
-  kdDebug() << "Replacing placeholders in: " << out << endl;
   out.replace(QRegExp("%u"),nickList.join(separator));
-  if(channelName) out.replace(QRegExp("%c"),channelName);
+  if(!channelName.isEmpty()) out.replace(QRegExp("%c"),channelName);
   out.replace(QRegExp("%o"),nickname);
   out.replace(QRegExp("%k"),channelKey);
   out.replace(QRegExp("%K"),serverKey);
   out.replace(QRegExp("%n"),"\n");
 //  out.replace(QRegExp("%f"),getFortuneCookie());
 //  out.replace(QRegExp("%p"),parameter);
-  if(queryName) out.replace(QRegExp("%q"),queryName);
+  if(!queryName.isEmpty()) out.replace(QRegExp("%q"),queryName);
 
   // finally replace all "%p" with "%"
   out.replace(QRegExp("%p"),"%");
@@ -1123,16 +1276,6 @@ OutputFilter& Server::getOutputFilter()
   return outputFilter;
 }
 
-ServerWindow* Server::getServerWindow()
-{
-  return serverWindow;
-}
-
-void Server::setServerWindow(ServerWindow* newWindow)
-{
-  serverWindow=newWindow;
-}
-
 void Server::away()
 {
   isAway=true;
@@ -1172,17 +1315,51 @@ bool Server::isAChannel(const QString &check)
   return (initial=='#' || initial=='&' || initial=='+' || initial=='!');
 }
 
-void Server::addRawLog()
+void Server::addRawLog(bool show)
 {
-  getServerWindow()->addRawLog();
+  if(!rawLog) rawLog=getMainWindow()->addRawLog(this);
+  // bring raw log to front since the main window does not do this for us
+  if(show) getMainWindow()->showView(rawLog);
 }
 
 void Server::closeRawLog()
 {
-  getServerWindow()->closeRawLog();
+  if(rawLog)
+  {
+    delete rawLog;
+    rawLog=0;
+  }
 }
 
-void Server::setIdentity(const Identity *newIdentity) { identity=newIdentity; }
-const Identity *Server::getIdentity() { return identity; }
+void Server::addChannelListPanel()
+{
+  if(!channelListPanel)
+  {
+    channelListPanel=getMainWindow()->addChannelListPanel(this);
+
+    connect(channelListPanel,SIGNAL (refreshChannelList()),this,SLOT (requestChannelList()) );
+    connect(channelListPanel,SIGNAL (joinChannel(const QString&)),this,SLOT (sendJoinCommand(const QString&)) );
+
+    connect(&inputFilter,SIGNAL (addToChannelList(const QString&,int,const QString&)),
+          channelListPanel,SLOT (addToChannelList(const QString&,int,const QString&)) );
+  }
+}
+
+ChannelListPanel* Server::getChannelListPanel() { return channelListPanel; }
+
+void Server::closeChannelListPanel()
+{
+  if(channelListPanel)
+  {
+    delete channelListPanel;
+    channelListPanel=0;
+  }
+}
+
+void Server::setIdentity(const Identity* newIdentity) { identity=newIdentity; }
+const Identity* Server::getIdentity() { return identity; }
+
+void Server::setMainWindow(KonversationMainWindow* newMainWindow) { mainWindow=newMainWindow; }
+KonversationMainWindow* Server::getMainWindow() { return mainWindow; }
 
 #include "server.moc"
