@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: server.h,v 1.47 2003/03/23 14:33:31 eisfuchs Exp $
+  $Id: server.h,v 1.60 2003/05/21 14:01:31 eisfuchs Exp $
 */
 
 #ifndef SERVER_H
@@ -22,11 +22,11 @@
 #include <qlist.h>
 #include <qtimer.h>
 #include <qdatetime.h>
+#include <qlistview.h>
 
 #include "inputfilter.h"
 #include "outputfilter.h"
 #include "ircserversocket.h"
-#include "identity.h"
 #include "ircresolver.h"
 
 /*
@@ -35,19 +35,24 @@
 
 class Channel;
 class Query;
-class ServerWindow;
+class StatusPanel;
+class Identity;
+class KonversationMainWindow;
+class RawLog;
+class ChannelListPanel;
 
 class Server : public QObject
 {
   Q_OBJECT
 
   public:
-    Server(int number);
+    Server(KonversationMainWindow* mainWindow,int number);
     ~Server();
 
     QString getServerName();
     const Identity *getIdentity();
     int getPort();
+    int getLag();
     bool getAutoJoin();
     void setAutoJoin(bool on);
 
@@ -81,11 +86,11 @@ class Server : public QObject
 
     void joinChannel(const QString& name, const QString& hostmask, const QString& key);
     void removeChannel(Channel* channel);
-    void appendToChannel(const char* channel,const char* nickname, const char* message);
-    void appendActionToChannel(const char* channel, const char* nickname, const char* message);
-    void appendServerMessageToChannel(const char* channel, const char* type, const char* message);
-    void appendCommandMessageToChannel(const char* channel, const char* command, const char* message);
-    void appendStatusMessage(const char* type,const char* message);
+    void appendToChannel(const QString& channel,const QString& nickname, const QString& message);
+    void appendActionToChannel(const QString& channel, const QString& nickname, const QString& message);
+    void appendServerMessageToChannel(const QString& channel, const QString& type, const QString& message);
+    void appendCommandMessageToChannel(const QString& channel, const QString& command, const QString& message);
+    void appendStatusMessage(const QString& type,const QString& message);
 
     void dcopSay(const QString& target,const QString& command);
     void dcopInfo(const QString& string);
@@ -95,37 +100,37 @@ class Server : public QObject
     void setChannelTopic(const QString& nickname, const QString& channel, const QString& topic); // Overloaded
     void updateChannelMode(const QString& nick, const QString& channel, char mode, bool plus, const QString& parameter);
     void updateChannelModeWidgets(const QString& channel, char mode, const QString& parameter);
-    void updateChannelQuickButtons(QStringList newButtons);
     void updateFonts();
     void setShowQuickButtons(bool state);
     void setShowModeButtons(bool state);
 
     QString getNextQueryName();
-    ServerWindow* getServerWindow();
-    void setServerWindow(ServerWindow* newWindow); // don't use this other than in ServerWindow!
+    void appendToQuery(const QString& queryName,const QString& message);
+    void appendActionToQuery(const QString& queryName,const QString& message);
+    void appendServerMessageToQuery(const QString& queryName,const QString& type,const QString& message);
+    void appendCommandMessageToQuery(const QString& queryName,const QString& command,const QString& message);
 
-    void appendToQuery(const char* queryName,const char* message);
-    void appendActionToQuery(const char* queryName,const char* message);
-    void appendServerMessageToQuery(const char* queryName, const char* type, const char* message);
-    void appendCommandMessageToQuery(const char* queryName, const char* command, const char* message);
-
-    Channel* getChannelByName(const char* name);
-    Query* getQueryByName(const char* name);
+    Channel* getChannelByName(const QString& name);
+    Query* getQueryByName(const QString& name);
     QString parseWildcards(const QString& toParse, const QString& nickname, const QString& channelName, const QString &channelKey, const QStringList& nickList, const QString& queryName, const QString& parameter);
     QString parseWildcards(const QString& toParse, const QString& nickname, const QString& channelName, const QString &channelKey, const QString& nick, const QString& queryName, const QString& parameter);
 
     QString getAutoJoinCommand();
 
+    void notifyAction(const QString& nick);
+    ChannelListPanel* getChannelListPanel();
+
   signals:
     void nicknameChanged(const QString&);
-    void serverLag(int msec);
-    void tooLongLag(int msec); // waiting too long for 303 response
+    void serverLag(int msec); // will be connected to StatusPanel::updateLag()
+    void serverLag(Server* server,int msec); // will be connected to KonversationMainWindow::updateLag()
+    void tooLongLag(Server* server, int msec); // will be connected to KonversationMainWindow::updateLag()
     void resetLag();
-    void nicksNowOnline(const QStringList& list); // Will be emitted when new 303 came in
-    void addDccPanel(); // will be connected to ServerWindow::addDccPanel()
-    void closeDccPanel(); // will be connected to ServerWindow::closeDccPanel()
+    void nicksNowOnline(Server* server,const QStringList& list); // Will be emitted when new 303 came in
+    void addDccPanel(); // will be connected to MainWindow::addDccPanel()
+    void addKonsolePanel(); // will be connected to MainWindow::addKonsolePanel()
+    void closeDccPanel(); // will be connected to MainWindow::closeDccPanel()
     void deleted(Server* myself); // will be connected to KonversationApplication::removeServer()
-    void repaintTabs(); // will be connected to LedTabBar::repaintTabs();
 
   public slots:
     void connectToIRCServer();
@@ -134,15 +139,24 @@ class Server : public QObject
     void addQuery(const QString &nickname, const QString &hostmask);
     void closeQuery(const QString &name);
     void closeChannel(const QString &name);
+    void quitServer();
+    void requestKonsolePanel();
     void requestDccPanel();
     void requestCloseDccPanel();
+    void requestBan(const QStringList& users,const QString& channel,const QString& option);
     void addDccSend(const QString &recipient,const QString &file);
     void removeQuery(Query *query);
     void startNotifyTimer(int msec=0);
+    void sendJoinCommand(const QString& channelName);
+    void requestChannelList();
+    void requestUserhost(const QString& nicks);
+    void addRawLog(bool show);
+    void closeRawLog();
+    void addChannelListPanel();
+    void closeChannelListPanel();
+    void updateChannelQuickButtons();
 
   protected slots:
-    void addRawLog();
-    void closeRawLog();
     void ircServerConnectionSuccess();
     void incoming();
     void processIncomingData();
@@ -166,11 +180,16 @@ class Server : public QObject
     void sendToAllChannels(const QString &text);
     void scriptNotFound(const QString& name);
     void scriptExecutionError(const QString& name);
+    void userhost(const QString& nick,const QString& hostmask,bool away,bool ircOp);
+    void setTopicAuthor(const QString& channel,const QString& author);
 
   protected:
     // constants
     static const int BUFFER_LEN=513;
 
+    KonversationMainWindow* getMainWindow();
+    void setMainWindow(KonversationMainWindow* newMainWindow);
+
     bool eventFilter(QObject* parent, QEvent *event);
 
     void lookupFinished();
@@ -188,7 +207,7 @@ class Server : public QObject
     int serverPort;
 
     IRCResolver resolver;
-    const Identity *identity;
+    const Identity* identity;
 
     bool autoJoin;
     bool autoRejoin;
@@ -198,7 +217,7 @@ class Server : public QObject
     QString autoJoinChannel;
     QString autoJoinChannelKey;
 
-    ServerWindow* serverWindow;
+    KonversationMainWindow* mainWindow;
     IRCServerSocket serverSocket;
 
     QTimer reconnectTimer;
@@ -209,6 +228,7 @@ class Server : public QObject
     QTime notifySent;
     QStringList notifyCache; // List of users found with ISON
     int checkTime;           // Time elapsed while waiting for server 303 response
+    int currentLag;
 
     QString ircName;
     QString inputBuffer;
@@ -223,6 +243,10 @@ class Server : public QObject
     InputFilter inputFilter;
     OutputFilter outputFilter;
 
+    StatusPanel* statusView;
+    RawLog* rawLog;
+    ChannelListPanel* channelListPanel;
+
     QDateTime awayTime;
     bool isAway;
 };
