@@ -11,7 +11,7 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: serverlistitem.cpp,v 1.5 2003/01/25 19:22:58 eisfuchs Exp $
+  $Id: serverlistitem.cpp,v 1.6 2003/02/10 19:16:28 eisfuchs Exp $
 */
 
 #include <kdebug.h>
@@ -24,7 +24,8 @@ ServerListItem::ServerListItem(QListView* parent,int newId,
                                QString arg2,
                                QString arg3,
                                QString arg4,
-                               QString arg5) :
+                               QString arg5,
+                               QString arg6) :
                 QCheckListItem(parent,QString::null,QCheckListItem::CheckBox)
 {
   id=newId;
@@ -34,6 +35,7 @@ ServerListItem::ServerListItem(QListView* parent,int newId,
   setText(4,arg3);
   setText(5,arg4);
   setText(6,arg5);
+  setText(7,arg6);
 }
 
 ServerListItem::~ServerListItem()
