@@ -11,7 +11,7 @@
   copyright: (C) 2003 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: statuspanel.h,v 1.2 2003/03/02 15:51:45 eisfuchs Exp $
+  $Id: statuspanel.h,v 1.5 2003/05/13 13:32:51 eisfuchs Exp $
 */
 
 #ifndef STATUSPANEL_H
@@ -19,14 +19,16 @@
 
 #include <qpushbutton.h>
 #include <qcheckbox.h>
+#include <qlabel.h>
 
 #include "chatwindow.h"
-#include "ircinput.h"
 
 /*
   @author Dario Abatianni
 */
 
+class IRCInput;
+
 class StatusPanel : public ChatWindow
 {
   Q_OBJECT
@@ -35,16 +37,22 @@ class StatusPanel : public ChatWindow
     StatusPanel(QWidget* parent);
     ~StatusPanel();
 
+    QString getTextInLine();
+    void closeYourself();
+
   signals:
-    void newText(QWidget* widget);
+    void newText(QWidget* widget,const QString& highlightColor);
     void sendFile();
-    
+    // will be connected to KonversationMainWindow::updateLag()
+    void lag(Server* server,int msec);
+
   public slots:
     void adjustFocus();
     void setNickname(const QString& newNickname);
-    void newTextInView();
+    void newTextInView(const QString& highlightColor);
     void updateFonts();
-
+    void updateLag(int msec);
+  
   protected slots:
     void sendFileMenu();
     void statusTextEntered();
@@ -57,6 +65,7 @@ class StatusPanel : public ChatWindow
     QPushButton* nicknameButton;
     IRCInput* statusInput;
     QCheckBox* logCheckBox;
+    QLabel* lagOMeter;
 };
 
 #endif
