@@ -11,15 +11,12 @@
   copyright: (C) 2002 by Dario Abatianni
   email:     eisfuchs@tigress.com
 
-  $Id: topiccombobox.cpp,v 1.5 2003/02/07 10:19:42 eisfuchs Exp $
+  $Id: topiccombobox.cpp,v 1.7 2003/05/10 11:12:21 eisfuchs Exp $
 */
 
 #include <kdebug.h>
 
-#include <qtextcodec.h>
-
 #include "topiccombobox.h"
-#include "konversationapplication.h"
 
 TopicComboBox::TopicComboBox(QWidget* parent) :
                    KComboBox(parent)
